PdfCore class

Constructors

PdfCore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

genThumbnailJpg(String pdfPath, String outPath, {int pageIndex = 0, String? password, int width = 200, int height = 200, int quality = 70, bool overrideImage = false}) Future<bool>
Gen Pdf Thumbnail JPG Type
genThumbnailPng(String pdfPath, String outPath, {int pageIndex = 0, String? password, int width = 200, int height = 200, bool overrideImage = false}) Future<bool>
Gen Pdf Thumbnail PNG Type
getAllPageSizedList(String path, {String? password}) Future<(List<PageSize>, String?)>
Get Pdf Page Size Class