FORM_DoDocumentJSAction function

  1. @Native<Void Function(FPDF_FORMHANDLE)>(FPDF_FORMHANDLE)>()
void FORM_DoDocumentJSAction(
  1. FPDF_FORMHANDLE hHandle
)

Function: FORM_DoDocumentJSAction This method is required for performing document-level JavaScript actions. It should be invoked after the PDF document has been loaded. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None. Comments: If there is document-level JavaScript action embedded in the document, this method will execute the JavaScript action. Otherwise, the method will do nothing.

Implementation

@ffi.Native<ffi.Void Function(FPDF_FORMHANDLE)>()
external void FORM_DoDocumentJSAction(FPDF_FORMHANDLE hHandle);