FORM_DoDocumentOpenAction function

  1. @Native<Void Function(FPDF_FORMHANDLE)>(FPDF_FORMHANDLE)>()
void FORM_DoDocumentOpenAction(
  1. FPDF_FORMHANDLE hHandle
)

Function: FORM_DoDocumentOpenAction This method is required for performing open-action when the document is opened. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None. Comments: This method will do nothing if there are no open-actions embedded in the document.

Implementation

@ffi.Native<ffi.Void Function(FPDF_FORMHANDLE)>()
external void FORM_DoDocumentOpenAction(FPDF_FORMHANDLE hHandle);