FORM_DoPageAAction function

  1. @Native<Void Function(FPDF_PAGE, FPDF_FORMHANDLE, Int)>(FPDF_PAGE, FPDF_FORMHANDLE, ffi.Int)>()
void FORM_DoPageAAction(
  1. FPDF_PAGE page,
  2. FPDF_FORMHANDLE hHandle,
  3. int aaType
)

Function: FORM_DoPageAAction This method is required for performing the page object's additional-action when opened or closed. Parameters: page - Handle to the page, as returned by FPDF_LoadPage(). hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). aaType - The type of the page object's additional-actions which defined above. Return Value: None. Comments: This method will do nothing if no additional-action corresponding to the specified |aaType| exists.

Implementation

@ffi.Native<ffi.Void Function(FPDF_PAGE, FPDF_FORMHANDLE, ffi.Int)>()
external void FORM_DoPageAAction(
  FPDF_PAGE page,
  FPDF_FORMHANDLE hHandle,
  int aaType,
);