FORM_ForceToKillFocus function

  1. @Native<FPDF_BOOL Function(FPDF_FORMHANDLE)>(FPDF_FORMHANDLE)>()
int FORM_ForceToKillFocus(
  1. FPDF_FORMHANDLE hHandle
)

Function: FORM_ForceToKillFocus. Call this member function to force to kill the focus of the form field which has focus. If it would kill the focus of a form field, save the value of form field if was changed by theuser. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: True indicates success; otherwise false.

Implementation

@ffi.Native<FPDF_BOOL Function(FPDF_FORMHANDLE)>()
external int FORM_ForceToKillFocus(FPDF_FORMHANDLE hHandle);