FORM_GetFocusedAnnot function

  1. @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, Pointer<Int>, Pointer<FPDF_ANNOTATION>)>(FPDF_FORMHANDLE, ffi.Pointer<ffi.Int>, ffi.Pointer<FPDF_ANNOTATION>)>()
int FORM_GetFocusedAnnot(
  1. FPDF_FORMHANDLE handle,
  2. Pointer<Int> page_index,
  3. Pointer<FPDF_ANNOTATION> annot
)

Experimental API. Function: FORM_GetFocusedAnnot. Call this member function to get the currently focused annotation. Parameters: handle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page_index - Buffer to hold the index number of the page which contains the focused annotation. 0 for the first page. Can't be NULL. annot - Buffer to hold the focused annotation. Can't be NULL. Return Value: On success, return true and write to the out parameters. Otherwise return false and leave the out parameters unmodified. Comments: Not currently supported for XFA forms - will report no focused annotation. Must call FPDFPage_CloseAnnot() when the annotation returned in |annot| by this function is no longer needed. This will return true and set |page_index| to -1 and |annot| to NULL, if there is no focused annotation.

Implementation

@ffi.Native<
  FPDF_BOOL Function(
    FPDF_FORMHANDLE,
    ffi.Pointer<ffi.Int>,
    ffi.Pointer<FPDF_ANNOTATION>,
  )
>()
external int FORM_GetFocusedAnnot(
  FPDF_FORMHANDLE handle,
  ffi.Pointer<ffi.Int> page_index,
  ffi.Pointer<FPDF_ANNOTATION> annot,
);