FORM_OnKeyDown function

  1. @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE, Int, Int)>(FPDF_FORMHANDLE, FPDF_PAGE, ffi.Int, ffi.Int)>()
int FORM_OnKeyDown(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. int nKeyCode,
  4. int modifier,
)

Function: FORM_OnKeyDown Call this member function when a nonsystem key is pressed. Parameters: hHandle - Handle to the form fill module, aseturned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). nKeyCode - The virtual-key code of the given key (see fpdf_fwlevent.h for virtual key codes). modifier - Mask of key flags (see fpdf_fwlevent.h for key flag values). Return Value: True indicates success; otherwise false.

Implementation

@ffi.Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE, ffi.Int, ffi.Int)>()
external int FORM_OnKeyDown(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  int nKeyCode,
  int modifier,
);