FORM_OnLButtonUp function
- FPDF_FORMHANDLE hHandle,
- FPDF_PAGE page,
- int modifier,
- double page_x,
- double page_y,
Function: FORM_OnLButtonUp Call this member function when the user releases the left mouse button. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). modifier - Indicates whether various virtual keys are down. page_x - Specifies the x-coordinate of the cursor in device. page_y - Specifies the y-coordinate of the cursor in device. Return Value: True indicates success; otherwise false.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_FORMHANDLE,
FPDF_PAGE,
ffi.Int,
ffi.Double,
ffi.Double,
)
>()
external int FORM_OnLButtonUp(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int modifier,
double page_x,
double page_y,
);