FORM_OnRButtonUp function
- FPDF_FORMHANDLE hHandle,
- FPDF_PAGE page,
- int modifier,
- double page_x,
- double page_y,
Function: FORM_OnRButtonUp Same as above, execpt for the right mouse button. Comments: At the present time, has no effect except in XFA builds, but is included for the sake of symmetry.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_FORMHANDLE,
FPDF_PAGE,
ffi.Int,
ffi.Double,
ffi.Double,
)
>()
external int FORM_OnRButtonUp(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int modifier,
double page_x,
double page_y,
);