FORM_Redo function
- @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE)>(FPDF_FORMHANDLE, FPDF_PAGE)>()
- FPDF_FORMHANDLE hHandle,
- FPDF_PAGE page
Function: FORM_Redo Make the current focused widget perform a redo operation. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). Return Value: True if the redo operation succeeded.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE)>()
external int FORM_Redo(FPDF_FORMHANDLE hHandle, FPDF_PAGE page);