FORM_ReplaceAndKeepSelection function

  1. @Native<Void Function(FPDF_FORMHANDLE, FPDF_PAGE, FPDF_WIDESTRING)>(FPDF_FORMHANDLE, FPDF_PAGE, FPDF_WIDESTRING)>()
void FORM_ReplaceAndKeepSelection(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. FPDF_WIDESTRING wsText
)

Experimental API Function: FORM_ReplaceAndKeepSelection Call this function to replace the selected text in a form text field or user-editable form combobox text field with another text string (which can be empty or non-empty). If there is no selected text, this function will append the replacement text after the current caret position. After the insertion, the inserted text will be selected. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as Returned by FPDF_LoadPage(). wsText - The text to be inserted, in UTF-16LE format. Return Value: None.

Implementation

@ffi.Native<ffi.Void Function(FPDF_FORMHANDLE, FPDF_PAGE, FPDF_WIDESTRING)>()
external void FORM_ReplaceAndKeepSelection(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  FPDF_WIDESTRING wsText,
);