FORM_SelectAllText function

  1. @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE)>(FPDF_FORMHANDLE, FPDF_PAGE)>()
int FORM_SelectAllText(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page
)

Experimental API Function: FORM_SelectAllText Call this function to select all the text within the currently focused form text field or form combobox text field. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). Return Value: Whether the operation succeeded or not.

Implementation

@ffi.Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE)>()
external int FORM_SelectAllText(FPDF_FORMHANDLE hHandle, FPDF_PAGE page);