FPDFAnnot_GetFontSize function

  1. @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_ANNOTATION, Pointer<Float>)>(FPDF_FORMHANDLE, FPDF_ANNOTATION, ffi.Pointer<ffi.Float>)>()
int FPDFAnnot_GetFontSize(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_ANNOTATION annot,
  3. Pointer<Float> value
)

Experimental API. Get the float value of the font size for an |annot| with variable text. If 0, the font is to be auto-sized: its size is computed as a function of the height of the annotation rectangle.

hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation. value - Required. Float which will be set to font size on success.

Returns true if the font size was set in |value|, false on error or if |value| not provided.

Implementation

@ffi.Native<
  FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_ANNOTATION, ffi.Pointer<ffi.Float>)
>()
external int FPDFAnnot_GetFontSize(
  FPDF_FORMHANDLE hHandle,
  FPDF_ANNOTATION annot,
  ffi.Pointer<ffi.Float> value,
);