FPDFAnnot_GetFormControlCount function

  1. @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_ANNOTATION)>(FPDF_FORMHANDLE, FPDF_ANNOTATION)>()
int FPDFAnnot_GetFormControlCount(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_ANNOTATION annot
)

Experimental API. Gets the count of annotations in the |annot|'s control group. A group of interactive form annotations is collectively called a form control group. Here, |annot|, an interactive form annotation, should be either a radio button or a checkbox.

hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation.

Returns number of controls in its control group or -1 on error.

Implementation

@ffi.Native<ffi.Int Function(FPDF_FORMHANDLE, FPDF_ANNOTATION)>()
external int FPDFAnnot_GetFormControlCount(
  FPDF_FORMHANDLE hHandle,
  FPDF_ANNOTATION annot,
);