FPDFAnnot_GetFormFieldAtPoint function

  1. @Native<FPDF_ANNOTATION Function(FPDF_FORMHANDLE hHandle, FPDF_PAGE page, Pointer<FS_POINTF> point)>(FPDF_FORMHANDLE, FPDF_PAGE, ffi.Pointer<FS_POINTF>)>()
FPDF_ANNOTATION FPDFAnnot_GetFormFieldAtPoint(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. Pointer<FS_POINTF> point
)

Experimental API. Retrieves an interactive form annotation whose rectangle contains a given point on a page. Must call FPDFPage_CloseAnnot() when the annotation returned is no longer needed.

hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment(). page - handle to the page, returned by FPDF_LoadPage function. point - position in PDF "user space".

Returns the interactive form annotation whose rectangle contains the given coordinates on the page. If there is no such annotation, return NULL.

Implementation

@ffi.Native<
  FPDF_ANNOTATION Function(FPDF_FORMHANDLE, FPDF_PAGE, ffi.Pointer<FS_POINTF>)
>()
external FPDF_ANNOTATION FPDFAnnot_GetFormFieldAtPoint(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  ffi.Pointer<FS_POINTF> point,
);