FPDFAnnot_GetInkListPath function

  1. @Native<UnsignedLong Function(FPDF_ANNOTATION, UnsignedLong, Pointer<FS_POINTF>, UnsignedLong)>(FPDF_ANNOTATION, ffi.UnsignedLong, ffi.Pointer<FS_POINTF>, ffi.UnsignedLong)>()
int FPDFAnnot_GetInkListPath(
  1. FPDF_ANNOTATION annot,
  2. int path_index,
  3. Pointer<FS_POINTF> buffer,
  4. int length,
)

Experimental API. Get a path in the ink list of an ink annotation. |buffer| is an array of points of the path. If |length| is less than the returned length, or |annot| or |buffer| is NULL, |buffer| will not be modified.

annot - handle to an annotation, as returned by e.g. FPDFPage_GetAnnot() path_index - index of the path buffer - buffer for holding the points. length - length of the buffer in points.

Returns the number of points of the path if the annotation is of type ink, 0 otherwise.

Implementation

@ffi.Native<
  ffi.UnsignedLong Function(
    FPDF_ANNOTATION,
    ffi.UnsignedLong,
    ffi.Pointer<FS_POINTF>,
    ffi.UnsignedLong,
  )
>()
external int FPDFAnnot_GetInkListPath(
  FPDF_ANNOTATION annot,
  int path_index,
  ffi.Pointer<FS_POINTF> buffer,
  int length,
);