FPDFAnnot_GetLine function

  1. @Native<FPDF_BOOL Function(FPDF_ANNOTATION, Pointer<FS_POINTF>, Pointer<FS_POINTF>)>(FPDF_ANNOTATION, ffi.Pointer<FS_POINTF>, ffi.Pointer<FS_POINTF>)>()
int FPDFAnnot_GetLine(
  1. FPDF_ANNOTATION annot,
  2. Pointer<FS_POINTF> start,
  3. Pointer<FS_POINTF> end
)

Experimental API. Get the starting and ending coordinates of a line annotation.

annot - handle to an annotation, as returned by e.g. FPDFPage_GetAnnot() start - starting point end - ending point

Returns true if the annotation is of type line, |start| and |end| are not NULL, false otherwise.

Implementation

@ffi.Native<
  FPDF_BOOL Function(
    FPDF_ANNOTATION,
    ffi.Pointer<FS_POINTF>,
    ffi.Pointer<FS_POINTF>,
  )
>()
external int FPDFAnnot_GetLine(
  FPDF_ANNOTATION annot,
  ffi.Pointer<FS_POINTF> start,
  ffi.Pointer<FS_POINTF> end,
);