FPDFAnnot_GetVertices function

  1. @Native<UnsignedLong Function(FPDF_ANNOTATION, Pointer<FS_POINTF>, UnsignedLong)>(FPDF_ANNOTATION, ffi.Pointer<FS_POINTF>, ffi.UnsignedLong)>()
int FPDFAnnot_GetVertices(
  1. FPDF_ANNOTATION annot,
  2. Pointer<FS_POINTF> buffer,
  3. int length
)

Experimental API. Get the vertices of a polygon or polyline annotation. |buffer| is an array of points of the annotation. If |length| is less than the returned length, or |annot| or |buffer| is NULL, |buffer| will not be modified.

annot - handle to an annotation, as returned by e.g. FPDFPage_GetAnnot() buffer - buffer for holding the points. length - length of the buffer in points.

Returns the number of points if the annotation is of type polygon or polyline, 0 otherwise.

Implementation

@ffi.Native<
  ffi.UnsignedLong Function(
    FPDF_ANNOTATION,
    ffi.Pointer<FS_POINTF>,
    ffi.UnsignedLong,
  )
>()
external int FPDFAnnot_GetVertices(
  FPDF_ANNOTATION annot,
  ffi.Pointer<FS_POINTF> buffer,
  int length,
);