FPDFAnnot_HasAttachmentPoints function

  1. @Native<FPDF_ANNOTATION_SUBTYPE Function(FPDF_ANNOTATION)>(FPDF_ANNOTATION)>()
int FPDFAnnot_HasAttachmentPoints(
  1. FPDF_ANNOTATION annot
)

Experimental API. Check if the annotation is of a type that has attachment points (i.e. quadpoints). Quadpoints are the vertices of the rectangle that encompasses the texts affected by the annotation. They provide the coordinates in the page where the annotation is attached. Only text markup annotations (i.e. highlight, strikeout, squiggly, and underline) and link annotations have quadpoints.

annot - handle to an annotation.

Returns true if the annotation is of a type that has quadpoints, false otherwise.

Implementation

@ffi.Native<FPDF_BOOL Function(FPDF_ANNOTATION)>()
external int FPDFAnnot_HasAttachmentPoints(FPDF_ANNOTATION annot);