FPDFAnnot_SetRect function

  1. @Native<FPDF_BOOL Function(FPDF_ANNOTATION, Pointer<FS_RECTF>)>(FPDF_ANNOTATION, ffi.Pointer<FS_RECTF>)>()
int FPDFAnnot_SetRect(
  1. FPDF_ANNOTATION annot,
  2. Pointer<FS_RECTF> rect
)

Experimental API. Set the annotation rectangle defining the location of the annotation. If the annotation's appearance stream is defined and this annotation is of a type without quadpoints, then update the bounding box too if the new rectangle defines a bigger one.

annot - handle to an annotation. rect - the annotation rectangle to be set.

Returns true if successful.

Implementation

@ffi.Native<FPDF_BOOL Function(FPDF_ANNOTATION, ffi.Pointer<FS_RECTF>)>()
external int FPDFAnnot_SetRect(
  FPDF_ANNOTATION annot,
  ffi.Pointer<FS_RECTF> rect,
);