FPDFAnnot_UpdateObject function
- @Native<FPDF_BOOL Function(FPDF_ANNOTATION, FPDF_PAGEOBJECT)>(FPDF_ANNOTATION, FPDF_PAGEOBJECT)>()
- FPDF_ANNOTATION annot,
- FPDF_PAGEOBJECT obj
Experimental API. Update |obj| in |annot|. |obj| must be in |annot| already and must have been retrieved by FPDFAnnot_GetObject(). Currently, only ink and stamp annotations are supported by this API. Also note that only path, image, and text objects have APIs for modification; see FPDFPath_(), FPDFText_(), and FPDFImageObj_*().
annot - handle to an annotation. obj - handle to the object that |annot| needs to update.
Return true if successful.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_ANNOTATION, FPDF_PAGEOBJECT)>()
external int FPDFAnnot_UpdateObject(FPDF_ANNOTATION annot, FPDF_PAGEOBJECT obj);