FPDFAvail_GetFirstPageNum function
- @Native<FPDF_BOOL Function(FPDF_DOCUMENT)>(FPDF_DOCUMENT)>()
- FPDF_DOCUMENT doc
Get the page number for the first available page in a linearized PDF.
doc - document handle.
Returns the zero-based index for the first available page.
For most linearized PDFs, the first available page will be the first page, however, some PDFs might make another page the first available page. For non-linearized PDFs, this function will always return zero.
Implementation
@ffi.Native<ffi.Int Function(FPDF_DOCUMENT)>()
external int FPDFAvail_GetFirstPageNum(FPDF_DOCUMENT doc);