FPDFBitmap_Destroy function

  1. @Native<Void Function(FPDF_BITMAP)>(FPDF_BITMAP)>()
void FPDFBitmap_Destroy(
  1. FPDF_BITMAP bitmap
)

Function: FPDFBitmap_Destroy Destroy a bitmap and release all related buffers. Parameters: bitmap - Handle to the bitmap. Returned by FPDFBitmap_Create or FPDFImageObj_GetBitmap. Return value: None. Comments: This function will not destroy any external buffers provided when the bitmap was created.

Implementation

@ffi.Native<ffi.Void Function(FPDF_BITMAP)>()
external void FPDFBitmap_Destroy(FPDF_BITMAP bitmap);