FPDFBitmap_FillRect function
- @Native<FPDF_BOOL Function(FPDF_BITMAP, Int, Int, Int, Int, FPDF_DWORD)>(FPDF_BITMAP, ffi.Int, ffi.Int, ffi.Int, ffi.Int, FPDF_DWORD)>()
Function: FPDFBitmap_FillRect Fill a rectangle in a bitmap. Parameters: bitmap - The handle to the bitmap. Returned by FPDFBitmap_Create. left - The left position. Starting from 0 at the left-most pixel. top - The top position. Starting from 0 at the top-most line. width - Width in pixels to be filled. height - Height in pixels to be filled. color - A 32-bit value specifing the color, in 8888 ARGB format. Return value: Returns whether the operation succeeded or not. Comments: This function sets the color and (optionally) alpha value in the specified region of the bitmap.
NOTE: If the alpha channel is used, this function does NOT composite the background with the source color, instead the background will be replaced by the source color and the alpha.
If the alpha channel is not used, the alpha parameter is ignored.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_BITMAP,
ffi.Int,
ffi.Int,
ffi.Int,
ffi.Int,
FPDF_DWORD,
)
>()
external int FPDFBitmap_FillRect(
FPDF_BITMAP bitmap,
int left,
int top,
int width,
int height,
int color,
);