FPDFBitmap_GetStride function

  1. @Native<Int Function(FPDF_BITMAP)>(FPDF_BITMAP)>()
int FPDFBitmap_GetStride(
  1. FPDF_BITMAP bitmap
)

Function: FPDFBitmap_GetStride Get number of bytes for each line in the bitmap buffer. Parameters: bitmap - Handle to the bitmap. Returned by FPDFBitmap_Create or FPDFImageObj_GetBitmap. Return value: The number of bytes for each line in the bitmap buffer. Comments: The stride may be more than width * number of bytes per pixel.

Implementation

@ffi.Native<ffi.Int Function(FPDF_BITMAP)>()
external int FPDFBitmap_GetStride(FPDF_BITMAP bitmap);