FPDFBookmark_GetAction function

  1. @Native<FPDF_ACTION Function(FPDF_BOOKMARK bookmark)>(FPDF_BOOKMARK)>()
FPDF_ACTION FPDFBookmark_GetAction(
  1. FPDF_BOOKMARK bookmark
)

Get the action associated with |bookmark|.

bookmark - handle to the bookmark.

Returns the handle to the action data, or NULL if no action is associated with |bookmark|. If this function returns a valid handle, it is valid as long as |bookmark| is valid. If this function returns NULL, FPDFBookmark_GetDest() should be called to get the |bookmark| destination data.

Implementation

@ffi.Native<FPDF_ACTION Function(FPDF_BOOKMARK)>()
external FPDF_ACTION FPDFBookmark_GetAction(FPDF_BOOKMARK bookmark);