FPDFBookmark_GetFirstChild function

  1. @Native<FPDF_BOOKMARK Function(FPDF_DOCUMENT document, FPDF_BOOKMARK bookmark)>(FPDF_DOCUMENT, FPDF_BOOKMARK)>()
FPDF_BOOKMARK FPDFBookmark_GetFirstChild(
  1. FPDF_DOCUMENT document,
  2. FPDF_BOOKMARK bookmark
)

Get the first child of |bookmark|, or the first top-level bookmark item.

document - handle to the document. bookmark - handle to the current bookmark. Pass NULL for the first top level item.

Returns a handle to the first child of |bookmark| or the first top-level bookmark item. NULL if no child or top-level bookmark found. Note that another name for the bookmarks is the document outline, as described in ISO 32000-1:2008, section 12.3.3.

Implementation

@ffi.Native<FPDF_BOOKMARK Function(FPDF_DOCUMENT, FPDF_BOOKMARK)>()
external FPDF_BOOKMARK FPDFBookmark_GetFirstChild(
  FPDF_DOCUMENT document,
  FPDF_BOOKMARK bookmark,
);