FPDFBookmark_GetNextSibling function

  1. @Native<FPDF_BOOKMARK Function(FPDF_DOCUMENT document, FPDF_BOOKMARK bookmark)>(FPDF_DOCUMENT, FPDF_BOOKMARK)>()
FPDF_BOOKMARK FPDFBookmark_GetNextSibling(
  1. FPDF_DOCUMENT document,
  2. FPDF_BOOKMARK bookmark
)

Get the next sibling of |bookmark|.

document - handle to the document. bookmark - handle to the current bookmark.

Returns a handle to the next sibling of |bookmark|, or NULL if this is the last bookmark at this level.

Note that the caller is responsible for handling circular bookmark references, as may arise from malformed documents.

Implementation

@ffi.Native<FPDF_BOOKMARK Function(FPDF_DOCUMENT, FPDF_BOOKMARK)>()
external FPDF_BOOKMARK FPDFBookmark_GetNextSibling(
  FPDF_DOCUMENT document,
  FPDF_BOOKMARK bookmark,
);