FPDFClipPath_CountPathSegments function

  1. @Native<Int Function(FPDF_CLIPPATH, Int)>(FPDF_CLIPPATH, ffi.Int)>()
int FPDFClipPath_CountPathSegments(
  1. FPDF_CLIPPATH clip_path,
  2. int path_index
)

Experimental API. Get number of segments inside one path of |clip_path|.

clip_path - handle to a clip_path. path_index - index into the array of paths of the clip path.

Returns the number of segments or -1 on failure.

Implementation

@ffi.Native<ffi.Int Function(FPDF_CLIPPATH, ffi.Int)>()
external int FPDFClipPath_CountPathSegments(
  FPDF_CLIPPATH clip_path,
  int path_index,
);