FPDFDest_GetLocationInPage function

  1. @Native<FPDF_BOOL Function(FPDF_DEST, Pointer<Int>, Pointer<Int>, Pointer<Int>, Pointer<Float>, Pointer<Float>, Pointer<Float>)>(FPDF_DEST, ffi.Pointer<FPDF_BOOL>, ffi.Pointer<FPDF_BOOL>, ffi.Pointer<FPDF_BOOL>, ffi.Pointer<FS_FLOAT>, ffi.Pointer<FS_FLOAT>, ffi.Pointer<FS_FLOAT>)>()
int FPDFDest_GetLocationInPage(
  1. FPDF_DEST dest,
  2. Pointer<Int> hasXVal,
  3. Pointer<Int> hasYVal,
  4. Pointer<Int> hasZoomVal,
  5. Pointer<Float> x,
  6. Pointer<Float> y,
  7. Pointer<Float> zoom,
)

Get the (x, y, zoom) location of |dest| in the destination page, if the destination is in page /XYZ x y zoom syntax.

dest - handle to the destination. hasXVal - out parameter; true if the x value is not null hasYVal - out parameter; true if the y value is not null hasZoomVal - out parameter; true if the zoom value is not null x - out parameter; the x coordinate, in page coordinates. y - out parameter; the y coordinate, in page coordinates. zoom - out parameter; the zoom value. Returns TRUE on successfully reading the /XYZ value.

Note the x, y, zoom values are only set if the corresponding hasXVal, hasYVal or hasZoomVal flags are true.

Implementation

@ffi.Native<
  FPDF_BOOL Function(
    FPDF_DEST,
    ffi.Pointer<FPDF_BOOL>,
    ffi.Pointer<FPDF_BOOL>,
    ffi.Pointer<FPDF_BOOL>,
    ffi.Pointer<FS_FLOAT>,
    ffi.Pointer<FS_FLOAT>,
    ffi.Pointer<FS_FLOAT>,
  )
>()
external int FPDFDest_GetLocationInPage(
  FPDF_DEST dest,
  ffi.Pointer<FPDF_BOOL> hasXVal,
  ffi.Pointer<FPDF_BOOL> hasYVal,
  ffi.Pointer<FPDF_BOOL> hasZoomVal,
  ffi.Pointer<FS_FLOAT> x,
  ffi.Pointer<FS_FLOAT> y,
  ffi.Pointer<FS_FLOAT> zoom,
);