FPDFFont_GetAscent function

  1. @Native<FPDF_BOOL Function(FPDF_FONT, Float, Pointer<Float>)>(FPDF_FONT, ffi.Float, ffi.Pointer<ffi.Float>)>()
int FPDFFont_GetAscent(
  1. FPDF_FONT font,
  2. double font_size,
  3. Pointer<Float> ascent
)

Experimental API. Get ascent distance of a font.

font - the handle to the font object. font_size - the size of the |font|. ascent - pointer where the font ascent will be stored

Ascent is the maximum distance in points above the baseline reached by the glyphs of the |font|. One point is 1/72 inch (around 0.3528 mm).

Returns TRUE on success; |ascent| unmodified on failure.

Implementation

@ffi.Native<FPDF_BOOL Function(FPDF_FONT, ffi.Float, ffi.Pointer<ffi.Float>)>()
external int FPDFFont_GetAscent(
  FPDF_FONT font,
  double font_size,
  ffi.Pointer<ffi.Float> ascent,
);