FPDFFont_GetFontData function
Experimental API. Get the decoded data from the |font| object.
font - The handle to the font object. (Required) buffer - The address of a buffer that receives the font data. buflen - Length of the buffer. out_buflen - Pointer to variable that will receive the minimum buffer size to contain the font data. Not filled if the return value is FALSE. (Required)
Returns TRUE on success. In which case, |out_buflen| will be filled, and |buffer| will be filled if it is large enough. Returns FALSE if any of the required parameters are null.
The decoded data is the uncompressed font data. i.e. the raw font data after having all stream filters applied, when the data is embedded.
If the font is not embedded, then this API will instead return the data for the substitution font it is using.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_FONT,
ffi.Pointer<ffi.Uint8>,
ffi.Size,
ffi.Pointer<ffi.Size>,
)
>()
external int FPDFFont_GetFontData(
FPDF_FONT font,
ffi.Pointer<ffi.Uint8> buffer,
int buflen,
ffi.Pointer<ffi.Size> out_buflen,
);