FPDFFont_GetGlyphWidth function
Experimental API. Get the width of a glyph in a font.
font - the handle to the font object. glyph - the glyph. font_size - the size of the font. width - pointer where the glyph width will be stored
Glyph width is the distance from the end of the prior glyph to the next glyph. This will be the vertical distance for vertical writing.
Returns TRUE on success; |width| unmodified on failure.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_FONT, ffi.Uint32, ffi.Float, ffi.Pointer<ffi.Float>)
>()
external int FPDFFont_GetGlyphWidth(
FPDF_FONT font,
int glyph,
double font_size,
ffi.Pointer<ffi.Float> width,
);