FPDFImageObj_GetImageDataRaw function
- @Native<UnsignedLong Function(FPDF_PAGEOBJECT, Pointer<
Void> , UnsignedLong)>(FPDF_PAGEOBJECT, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)>()
- FPDF_PAGEOBJECT image_object,
- Pointer<
Void> buffer, - int buflen
Get the raw image data of |image_object|. The raw data is the image data as stored in the PDF without applying any filters. |buffer| is only modified if |buflen| is longer than the length of the raw image data.
image_object - handle to an image object. buffer - buffer for holding the raw image data. buflen - length of the buffer in bytes.
Returns the length of the raw image data.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_PAGEOBJECT,
ffi.Pointer<ffi.Void>,
ffi.UnsignedLong,
)
>()
external int FPDFImageObj_GetImageDataRaw(
FPDF_PAGEOBJECT image_object,
ffi.Pointer<ffi.Void> buffer,
int buflen,
);