FPDFImageObj_GetImageMetadata function
- @Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, FPDF_PAGE, Pointer<
FPDF_IMAGEOBJ_METADATA> )>(FPDF_PAGEOBJECT, FPDF_PAGE, ffi.Pointer<FPDF_IMAGEOBJ_METADATA>)>()
- FPDF_PAGEOBJECT image_object,
- FPDF_PAGE page,
- Pointer<
FPDF_IMAGEOBJ_METADATA> metadata
Get the image metadata of |image_object|, including dimension, DPI, bits per pixel, and colorspace. If the |image_object| is not an image object or if it does not have an image, then the return value will be false. Otherwise, failure to retrieve any specific parameter would result in its value being 0.
image_object - handle to an image object. page - handle to the page that |image_object| is on. Required for retrieving the image's bits per pixel and colorspace. metadata - receives the image metadata; must not be NULL.
Returns true if successful.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_PAGEOBJECT,
FPDF_PAGE,
ffi.Pointer<FPDF_IMAGEOBJ_METADATA>,
)
>()
external int FPDFImageObj_GetImageMetadata(
FPDF_PAGEOBJECT image_object,
FPDF_PAGE page,
ffi.Pointer<FPDF_IMAGEOBJ_METADATA> metadata,
);