FPDFImageObj_LoadJpegFileInline function
- @Native<FPDF_BOOL Function(Pointer<
FPDF_PAGE> , Int, FPDF_PAGEOBJECT, Pointer<FPDF_FILEACCESS> )>(ffi.Pointer<FPDF_PAGE>, ffi.Int, FPDF_PAGEOBJECT, ffi.Pointer<FPDF_FILEACCESS>)>()
- Pointer<
FPDF_PAGE> pages, - int count,
- FPDF_PAGEOBJECT image_object,
- Pointer<
FPDF_FILEACCESS> file_access,
Load an image from a JPEG image file and then set it into |image_object|.
pages - pointer to the start of all loaded pages, may be NULL. count - number of |pages|, may be 0. image_object - handle to an image object. file_access - file access handler which specifies the JPEG image file.
Returns TRUE on success.
The image object might already have an associated image, which is shared and cached by the loaded pages. In that case, we need to clear the cached image for all the loaded pages. Pass |pages| and page count (|count|) to this API to clear the image cache. If the image is not previously shared, or NULL is a valid |pages| value. This function loads the JPEG image inline, so the image content is copied to the file. This allows |file_access| and its associated data to be deleted after this function returns.
Implementation
@ffi.Native<
FPDF_BOOL Function(
ffi.Pointer<FPDF_PAGE>,
ffi.Int,
FPDF_PAGEOBJECT,
ffi.Pointer<FPDF_FILEACCESS>,
)
>()
external int FPDFImageObj_LoadJpegFileInline(
ffi.Pointer<FPDF_PAGE> pages,
int count,
FPDF_PAGEOBJECT image_object,
ffi.Pointer<FPDF_FILEACCESS> file_access,
);