FPDFLink_GetRect function

  1. @Native<FPDF_BOOL Function(FPDF_PAGELINK, Int, Int, Pointer<Double>, Pointer<Double>, Pointer<Double>, Pointer<Double>)>(FPDF_PAGELINK, ffi.Int, ffi.Int, ffi.Pointer<ffi.Double>, ffi.Pointer<ffi.Double>, ffi.Pointer<ffi.Double>, ffi.Pointer<ffi.Double>)>()
int FPDFLink_GetRect(
  1. FPDF_PAGELINK link_page,
  2. int link_index,
  3. int rect_index,
  4. Pointer<Double> left,
  5. Pointer<Double> top,
  6. Pointer<Double> right,
  7. Pointer<Double> bottom,
)

Function: FPDFLink_GetRect Fetch the boundaries of a rectangle for a link. Parameters: link_page - Handle returned by FPDFLink_LoadWebLinks. link_index - Zero-based index for the link. rect_index - Zero-based index for a rectangle. left - Pointer to a double value receiving the rectangle left boundary. top - Pointer to a double value receiving the rectangle top boundary. right - Pointer to a double value receiving the rectangle right boundary. bottom - Pointer to a double value receiving the rectangle bottom boundary. Return Value: On success, return TRUE and fill in |left|, |top|, |right|, and |bottom|. If |link_page| is invalid or if |link_index| does not correspond to a valid link, then return FALSE, and the out parameters remain unmodified.

Implementation

@ffi.Native<
  FPDF_BOOL Function(
    FPDF_PAGELINK,
    ffi.Int,
    ffi.Int,
    ffi.Pointer<ffi.Double>,
    ffi.Pointer<ffi.Double>,
    ffi.Pointer<ffi.Double>,
    ffi.Pointer<ffi.Double>,
  )
>()
external int FPDFLink_GetRect(
  FPDF_PAGELINK link_page,
  int link_index,
  int rect_index,
  ffi.Pointer<ffi.Double> left,
  ffi.Pointer<ffi.Double> top,
  ffi.Pointer<ffi.Double> right,
  ffi.Pointer<ffi.Double> bottom,
);