FPDFLink_LoadWebLinks function
- @Native<FPDF_PAGELINK Function(FPDF_TEXTPAGE text_page)>(FPDF_TEXTPAGE)>()
- FPDF_TEXTPAGE text_page
Function: FPDFLink_LoadWebLinks Prepare information about weblinks in a page. Parameters: text_page - Handle to a text page information structure. Returned by FPDFText_LoadPage function. Return Value: A handle to the page's links information structure, or NULL if something goes wrong. Comments: Weblinks are those links implicitly embedded in PDF pages. PDF also has a type of annotation called "link" (FPDFTEXT doesn't deal with that kind of link). FPDFTEXT weblink feature is useful for automatically detecting links in the page contents. For example, things like "https://www.example.com" will be detected, so applications can allow user to click on those characters to activate the link, even the PDF doesn't come with link annotations.
FPDFLink_CloseWebLinks must be called to release resources.
Implementation
@ffi.Native<FPDF_PAGELINK Function(FPDF_TEXTPAGE)>()
external FPDF_PAGELINK FPDFLink_LoadWebLinks(FPDF_TEXTPAGE text_page);