FPDFPageObjMark_GetParamFloatValue function
- @Native<FPDF_BOOL Function(FPDF_PAGEOBJECTMARK, FPDF_BYTESTRING, Pointer<
Float> )>(FPDF_PAGEOBJECTMARK, FPDF_BYTESTRING, ffi.Pointer<ffi.Float>)>()
- FPDF_PAGEOBJECTMARK mark,
- FPDF_BYTESTRING key,
- Pointer<
Float> out_value
Experimental API. Get the value of a number property in a content mark by key as float. FPDFPageObjMark_GetParamValueType() should have returned FPDF_OBJECT_NUMBER for this property.
mark - handle to a content mark. key - string key of the property. out_value - pointer to variable that will receive the value. Not filled if false is returned.
Returns TRUE if the key maps to a number value, FALSE otherwise.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_PAGEOBJECTMARK,
FPDF_BYTESTRING,
ffi.Pointer<ffi.Float>,
)
>()
external int FPDFPageObjMark_GetParamFloatValue(
FPDF_PAGEOBJECTMARK mark,
FPDF_BYTESTRING key,
ffi.Pointer<ffi.Float> out_value,
);