FPDFPageObjMark_GetParamKey function
- @Native<FPDF_BOOL Function(FPDF_PAGEOBJECTMARK, UnsignedLong, Pointer<
FPDF_WCHAR> , UnsignedLong, Pointer<UnsignedLong> )>(FPDF_PAGEOBJECTMARK, ffi.UnsignedLong, ffi.Pointer<FPDF_WCHAR>, ffi.UnsignedLong, ffi.Pointer<ffi.UnsignedLong>)>()
- FPDF_PAGEOBJECTMARK mark,
- int index,
- Pointer<
FPDF_WCHAR> buffer, - int buflen,
- Pointer<
UnsignedLong> out_buflen,
Experimental API. Get the key of a property in a content mark.
mark - handle to a content mark. index - index of the property. buffer - buffer for holding the returned key in UTF-16LE. This is only modified if |buflen| is large enough to store the key. Optional, pass null to just retrieve the size of the buffer needed. buflen - length of the buffer in bytes. out_buflen - pointer to variable that will receive the minimum buffer size in bytes to contain the name. This is a required parameter. Not filled if FALSE is returned.
Returns TRUE if the operation was successful, FALSE otherwise.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_PAGEOBJECTMARK,
ffi.UnsignedLong,
ffi.Pointer<FPDF_WCHAR>,
ffi.UnsignedLong,
ffi.Pointer<ffi.UnsignedLong>,
)
>()
external int FPDFPageObjMark_GetParamKey(
FPDF_PAGEOBJECTMARK mark,
int index,
ffi.Pointer<FPDF_WCHAR> buffer,
int buflen,
ffi.Pointer<ffi.UnsignedLong> out_buflen,
);