FPDFPageObj_AddMark function

  1. @Native<FPDF_PAGEOBJECTMARK Function(FPDF_PAGEOBJECT page_object, FPDF_BYTESTRING name)>(FPDF_PAGEOBJECT, FPDF_BYTESTRING)>()
FPDF_PAGEOBJECTMARK FPDFPageObj_AddMark(
  1. FPDF_PAGEOBJECT page_object,
  2. FPDF_BYTESTRING name
)

Experimental API. Add a new content mark to a |page_object|.

page_object - handle to a page object. name - the name (tag) of the mark.

Returns the handle to the content mark, or NULL on failure. The handle is still owned by the library, and it should not be freed directly. It becomes invalid if the page object is destroyed, either directly or indirectly by unloading the page.

Implementation

@ffi.Native<FPDF_PAGEOBJECTMARK Function(FPDF_PAGEOBJECT, FPDF_BYTESTRING)>()
external FPDF_PAGEOBJECTMARK FPDFPageObj_AddMark(
  FPDF_PAGEOBJECT page_object,
  FPDF_BYTESTRING name,
);