FPDFPageObj_CreateNewRect function

  1. @Native<FPDF_PAGEOBJECT Function(Float, Float, Float, Float)>(ffi.Float, ffi.Float, ffi.Float, ffi.Float)>()
FPDF_PAGEOBJECT FPDFPageObj_CreateNewRect(
  1. double x,
  2. double y,
  3. double w,
  4. double h,
)

Create a closed path consisting of a rectangle.

x - horizontal position for the left boundary of the rectangle. y - vertical position for the bottom boundary of the rectangle. w - width of the rectangle. h - height of the rectangle.

Returns a handle to the new path object.

Implementation

@ffi.Native<
  FPDF_PAGEOBJECT Function(ffi.Float, ffi.Float, ffi.Float, ffi.Float)
>()
external FPDF_PAGEOBJECT FPDFPageObj_CreateNewRect(
  double x,
  double y,
  double w,
  double h,
);