FPDFPageObj_CreateTextObj function

  1. @Native<FPDF_PAGEOBJECT Function(FPDF_DOCUMENT, FPDF_FONT, Float)>(FPDF_DOCUMENT, FPDF_FONT, ffi.Float)>()
FPDF_PAGEOBJECT FPDFPageObj_CreateTextObj(
  1. FPDF_DOCUMENT document,
  2. FPDF_FONT font,
  3. double font_size
)

Create a new text object using a loaded font.

document - handle to the document. font - handle to the font object. font_size - the font size for the new text object.

Returns a handle to a new text object, or NULL on failure

Implementation

@ffi.Native<FPDF_PAGEOBJECT Function(FPDF_DOCUMENT, FPDF_FONT, ffi.Float)>()
external FPDF_PAGEOBJECT FPDFPageObj_CreateTextObj(
  FPDF_DOCUMENT document,
  FPDF_FONT font,
  double font_size,
);