FPDFPageObj_GetClipPath function

  1. @Native<FPDF_CLIPPATH Function(FPDF_PAGEOBJECT page_object)>(FPDF_PAGEOBJECT)>()
FPDF_CLIPPATH FPDFPageObj_GetClipPath(
  1. FPDF_PAGEOBJECT page_object
)

Experimental API. Get the clip path of the page object.

page object - Handle to a page object. Returned by e.g. FPDFPage_GetObject().

Returns the handle to the clip path, or NULL on failure. The caller does not take ownership of the returned FPDF_CLIPPATH. Instead, it remains valid until FPDF_ClosePage() is called for the page containing |page_object|.

Implementation

@ffi.Native<FPDF_CLIPPATH Function(FPDF_PAGEOBJECT)>()
external FPDF_CLIPPATH FPDFPageObj_GetClipPath(FPDF_PAGEOBJECT page_object);