FPDFPageObj_GetMatrix function
- @Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, Pointer<
FS_MATRIX> )>(FPDF_PAGEOBJECT, ffi.Pointer<FS_MATRIX>)>()
- FPDF_PAGEOBJECT page_object,
- Pointer<
FS_MATRIX> matrix
Experimental API. Get the transform matrix of a page object.
page_object - handle to a page object. matrix - pointer to struct to receive the matrix value.
The matrix is composed as: |a c e| |b d f| and used to scale, rotate, shear and translate the page object.
For page objects outside form objects, the matrix values are relative to the page that contains it. For page objects inside form objects, the matrix values are relative to the form that contains it.
Returns TRUE on success.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, ffi.Pointer<FS_MATRIX>)>()
external int FPDFPageObj_GetMatrix(
FPDF_PAGEOBJECT page_object,
ffi.Pointer<FS_MATRIX> matrix,
);