FPDFPageObj_SetIsActive function

  1. @Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, FPDF_BOOL)>(FPDF_PAGEOBJECT, FPDF_BOOL)>()
int FPDFPageObj_SetIsActive(
  1. FPDF_PAGEOBJECT page_object,
  2. int active
)

Experimental API. Sets if |page_object| is active within page.

page_object - handle to a page object. active - a boolean specifying if the object is active.

Returns TRUE on success.

Page objects all start in the active state by default, and remain in that state unless this function is called.

When |active| is false, this makes the |page_object| be treated as if it wasn't in the document even though it is still held internally.

Implementation

@ffi.Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, FPDF_BOOL)>()
external int FPDFPageObj_SetIsActive(FPDF_PAGEOBJECT page_object, int active);