FPDFPage_CloseAnnot function

  1. @Native<Void Function(FPDF_ANNOTATION)>(FPDF_ANNOTATION)>()
void FPDFPage_CloseAnnot(
  1. FPDF_ANNOTATION annot
)

Experimental API. Close an annotation. Must be called when the annotation returned by FPDFPage_CreateAnnot() or FPDFPage_GetAnnot() is no longer needed. This function does not remove the annotation from the document.

annot - handle to an annotation.

Implementation

@ffi.Native<ffi.Void Function(FPDF_ANNOTATION)>()
external void FPDFPage_CloseAnnot(FPDF_ANNOTATION annot);