FPDFPage_CreateAnnot function
- @Native<FPDF_ANNOTATION Function(FPDF_PAGE, FPDF_ANNOTATION_SUBTYPE)>(FPDF_PAGE, FPDF_ANNOTATION_SUBTYPE)>()
Experimental API. Create an annotation in |page| of the subtype |subtype|. If the specified subtype is illegal or unsupported, then a new annotation will not be created. Must call FPDFPage_CloseAnnot() when the annotation returned by this function is no longer needed.
page - handle to a page. subtype - the subtype of the new annotation.
Returns a handle to the new annotation object, or NULL on failure.
Implementation
@ffi.Native<FPDF_ANNOTATION Function(FPDF_PAGE, FPDF_ANNOTATION_SUBTYPE)>()
external FPDF_ANNOTATION FPDFPage_CreateAnnot(FPDF_PAGE page, int subtype);