FPDFPage_GetMediaBox function

  1. @Native<FPDF_BOOL Function(FPDF_PAGE, Pointer<Float>, Pointer<Float>, Pointer<Float>, Pointer<Float>)>(FPDF_PAGE, ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>)>()
int FPDFPage_GetMediaBox(
  1. FPDF_PAGE page,
  2. Pointer<Float> left,
  3. Pointer<Float> bottom,
  4. Pointer<Float> right,
  5. Pointer<Float> top,
)

Get "MediaBox" entry from the page dictionary.

page - Handle to a page. left - Pointer to a float value receiving the left of the rectangle. bottom - Pointer to a float value receiving the bottom of the rectangle. right - Pointer to a float value receiving the right of the rectangle. top - Pointer to a float value receiving the top of the rectangle.

On success, return true and write to the out parameters. Otherwise return false and leave the out parameters unmodified.

Implementation

@ffi.Native<
  FPDF_BOOL Function(
    FPDF_PAGE,
    ffi.Pointer<ffi.Float>,
    ffi.Pointer<ffi.Float>,
    ffi.Pointer<ffi.Float>,
    ffi.Pointer<ffi.Float>,
  )
>()
external int FPDFPage_GetMediaBox(
  FPDF_PAGE page,
  ffi.Pointer<ffi.Float> left,
  ffi.Pointer<ffi.Float> bottom,
  ffi.Pointer<ffi.Float> right,
  ffi.Pointer<ffi.Float> top,
);