FPDFPage_InsertObjectAtIndex function
- @Native<FPDF_BOOL Function(FPDF_PAGE, FPDF_PAGEOBJECT, Size)>(FPDF_PAGE, FPDF_PAGEOBJECT, ffi.Size)>()
- FPDF_PAGE page,
- FPDF_PAGEOBJECT page_object,
- int index
Insert |page_object| into |page| at the specified |index|.
page - handle to a page page_object - handle to a page object as previously obtained by FPDFPageObj_CreateNew{Path|Rect}() or FPDFPageObj_New{Text|Image}Obj(). Ownership of the object is transferred back to PDFium. index - the index position to insert the object at. If index equals the current object count, the object will be appended to the end. If index is greater than the object count, the function will fail and return false.
Returns true if successful.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_PAGE, FPDF_PAGEOBJECT, ffi.Size)>()
external int FPDFPage_InsertObjectAtIndex(
FPDF_PAGE page,
FPDF_PAGEOBJECT page_object,
int index,
);