FPDFPage_New function

  1. @Native<FPDF_PAGE Function(FPDF_DOCUMENT, Int, Double, Double)>(FPDF_DOCUMENT, ffi.Int, ffi.Double, ffi.Double)>()
FPDF_PAGE FPDFPage_New(
  1. FPDF_DOCUMENT document,
  2. int page_index,
  3. double width,
  4. double height,
)

Create a new PDF page.

document - handle to document. page_index - suggested 0-based index of the page to create. If it is larger than document's current last index(L), the created page index is the next available index -- L+1. width - the page width in points. height - the page height in points.

Returns the handle to the new page or NULL on failure.

The page should be closed with FPDF_ClosePage() when finished as with any other page in the document.

Implementation

@ffi.Native<
  FPDF_PAGE Function(FPDF_DOCUMENT, ffi.Int, ffi.Double, ffi.Double)
>()
external FPDF_PAGE FPDFPage_New(
  FPDF_DOCUMENT document,
  int page_index,
  double width,
  double height,
);