FPDFText_SetCharcodes function

  1. @Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, Pointer<Uint32>, Size)>(FPDF_PAGEOBJECT, ffi.Pointer<ffi.Uint32>, ffi.Size)>()
int FPDFText_SetCharcodes(
  1. FPDF_PAGEOBJECT text_object,
  2. Pointer<Uint32> charcodes,
  3. int count
)

Experimental API. Set the text using charcodes for a text object. If it had text, it will be replaced.

text_object - handle to the text object. charcodes - pointer to an array of charcodes to be added. count - number of elements in |charcodes|.

Returns TRUE on success. Fails if |text_object| or |charcodes| is null, or |count| is 0.

Implementation

@ffi.Native<
  FPDF_BOOL Function(FPDF_PAGEOBJECT, ffi.Pointer<ffi.Uint32>, ffi.Size)
>()
external int FPDFText_SetCharcodes(
  FPDF_PAGEOBJECT text_object,
  ffi.Pointer<ffi.Uint32> charcodes,
  int count,
);