FPDFText_SetPositions function
Experimental API. Set the character positions for a text object.
text_object - handle to the text object. positions - pointer to an array of character positions to be set. count - number of elements in |positions|.
The |positions| array specifies the position in points for each character except the first one. The first character has an implied position value of 0. All positions are relative to the origin of the text object. The direction is either horizontal or vertical, depending on the direction of text in |text_object|.
For a text object with N characters, |count| must be N - 1. Therefore this API fails when N <= 1.
Returns TRUE on success.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_PAGEOBJECT, ffi.Pointer<ffi.Float>, ffi.Size)
>()
external int FPDFText_SetPositions(
FPDF_PAGEOBJECT text_object,
ffi.Pointer<ffi.Float> positions,
int count,
);