FPDF_AddInstalledFont function

  1. @Native<Void Function(Pointer<Void>, Pointer<Char>, Int)>(ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Char>, ffi.Int)>()
void FPDF_AddInstalledFont(
  1. Pointer<Void> mapper,
  2. Pointer<Char> face,
  3. int charset
)

Function: FPDF_AddInstalledFont Add a system font to the list in PDFium. Comments: This function is only called during the system font list building process. Parameters: mapper - Opaque pointer to Foxit font mapper face - The font face name charset - Font character set. See above defined constants. Return Value: None.

Implementation

@ffi.Native<
  ffi.Void Function(ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Char>, ffi.Int)
>()
external void FPDF_AddInstalledFont(
  ffi.Pointer<ffi.Void> mapper,
  ffi.Pointer<ffi.Char> face,
  int charset,
);