FPDF_BSTR_ class final

Structure for persisting a string beyond the duration of a callback. Note: although represented as a char*, string may be interpreted as a UTF-16LE formated string. Used only by XFA callbacks.

Inheritance
Implemented types
Available extensions

Constructors

FPDF_BSTR_()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
len int
Length of the string, in bytes.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
str Pointer<Char>
String buffer, manipulate only with FPDF_BStr_* methods.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited