FPDF_CreateNewDocument function
Create a new PDF document.
Returns a handle to a new document, or NULL on failure.
Implementation
@ffi.Native<FPDF_DOCUMENT Function()>()
external FPDF_DOCUMENT FPDF_CreateNewDocument();
Create a new PDF document.
Returns a handle to a new document, or NULL on failure.
@ffi.Native<FPDF_DOCUMENT Function()>()
external FPDF_DOCUMENT FPDF_CreateNewDocument();