FPDF_FFLDraw function

  1. @Native<Void Function(FPDF_FORMHANDLE, FPDF_BITMAP, FPDF_PAGE, Int, Int, Int, Int, Int, Int)>(FPDF_FORMHANDLE, FPDF_BITMAP, FPDF_PAGE, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int)>()
void FPDF_FFLDraw(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_BITMAP bitmap,
  3. FPDF_PAGE page,
  4. int start_x,
  5. int start_y,
  6. int size_x,
  7. int size_y,
  8. int rotate,
  9. int flags,
)

Function: FPDF_FFLDraw Render FormFields and popup window on a page to a device independent bitmap. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). bitmap - Handle to the device independent bitmap (as the output buffer). Bitmap handles can be created by FPDFBitmap_Create(). page - Handle to the page, as returned by FPDF_LoadPage(). start_x - Left pixel position of the display area in the device coordinates. start_y - Top pixel position of the display area in the device coordinates. size_x - Horizontal size (in pixels) for displaying the page. size_y - Vertical size (in pixels) for displaying the page. rotate - Page orientation: 0 (normal), 1 (rotated 90 degrees clockwise), 2 (rotated 180 degrees), 3 (rotated 90 degrees counter-clockwise). flags - 0 for normal display, or combination of flags defined above. Return Value: None. Comments: This function is designed to render annotations that are user-interactive, which are widget annotations (for FormFields) and popup annotations. With the FPDF_ANNOT flag, this function will render a popup annotation when users mouse-hover on a non-widget annotation. Regardless of FPDF_ANNOT flag, this function will always render widget annotations for FormFields. In order to implement the FormFill functions, implementation should call this function after rendering functions, such as FPDF_RenderPageBitmap() or FPDF_RenderPageBitmap_Start(), have finished rendering the page contents.

Implementation

@ffi.Native<
  ffi.Void Function(
    FPDF_FORMHANDLE,
    FPDF_BITMAP,
    FPDF_PAGE,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
  )
>()
external void FPDF_FFLDraw(
  FPDF_FORMHANDLE hHandle,
  FPDF_BITMAP bitmap,
  FPDF_PAGE page,
  int start_x,
  int start_y,
  int size_x,
  int size_y,
  int rotate,
  int flags,
);