FPDF_FILEACCESS class final

Structure for custom file access.

Inheritance
Implemented types
Available extensions

Constructors

FPDF_FILEACCESS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
m_FileLen int
File length, in bytes.
getter/setter pair
m_GetBlock Pointer<NativeFunction<Int Function(Pointer<Void> param, UnsignedLong position, Pointer<UnsignedChar> pBuf, UnsignedLong size)>>
A function pointer for getting a block of data from a specific position. Position is specified by byte offset from the beginning of the file. The pointer to the buffer is never NULL and the size is never 0. The position and size will never go out of range of the file length. It may be possible for PDFium to call this function multiple times for the same position. Return value: should be non-zero if successful, zero for error.
getter/setter pair
m_Param Pointer<Void>
A custom pointer for all implementation specific data. This pointer will be used as the first parameter to the m_GetBlock callback.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited