m_GetBlock property
Pointer<NativeFunction<Int Function(Pointer<Void> param, UnsignedLong position, Pointer<UnsignedChar> pBuf, UnsignedLong size)> >
m_GetBlock
getter/setter pair
A function pointer for getting a block of data from a specific position. Position is specified by byte offset from the beginning of the file. The pointer to the buffer is never NULL and the size is never 0. The position and size will never go out of range of the file length. It may be possible for PDFium to call this function multiple times for the same position. Return value: should be non-zero if successful, zero for error.
Implementation
external ffi.Pointer<
ffi.NativeFunction<
ffi.Int Function(
ffi.Pointer<ffi.Void> param,
ffi.UnsignedLong position,
ffi.Pointer<ffi.UnsignedChar> pBuf,
ffi.UnsignedLong size,
)
>
>
m_GetBlock;