ReadBlock property
Pointer<NativeFunction<FPDF_RESULT Function(Pointer<Void> clientData, FPDF_DWORD offset, Pointer<Void> buffer, FPDF_DWORD size)> >
ReadBlock
getter/setter pair
Callback function to read data from the current file stream.
Parameters: clientData - Pointer to user-defined data. offset - Offset position starts from the beginning of file stream. This parameter indicates reading position. buffer - Memory buffer to store data which are read from file stream. This parameter should not be NULL. size - Size of data which should be read from file stream, in bytes. The buffer indicated by |buffer| must be large enough to store specified data. Returns: 0 for success, other value for failure.
Implementation
external ffi.Pointer<
ffi.NativeFunction<
FPDF_RESULT Function(
ffi.Pointer<ffi.Void> clientData,
FPDF_DWORD offset,
ffi.Pointer<ffi.Void> buffer,
FPDF_DWORD size,
)
>
>
ReadBlock;