FPDF_GetDefaultTTFMap function
- @Native<Pointer<
FPDF_CharsetFontMap> Function()>()>()
Function: FPDF_GetDefaultTTFMap Returns a pointer to the default character set to TT Font name map. The map is an array of FPDF_CharsetFontMap structs, with its end indicated by a { -1, NULL } entry. Parameters: None. Return Value: Pointer to the Charset Font Map. Note: Once FPDF_GetDefaultTTFMapCount() and FPDF_GetDefaultTTFMapEntry() are no longer experimental, this API will be marked as deprecated. See https://crbug.com/348468114
Implementation
@ffi.Native<ffi.Pointer<FPDF_CharsetFontMap> Function()>()
external ffi.Pointer<FPDF_CharsetFontMap> FPDF_GetDefaultTTFMap();