FPDF_GetDocUserPermissions function

  1. @Native<UnsignedLong Function(FPDF_DOCUMENT)>(FPDF_DOCUMENT)>()
int FPDF_GetDocUserPermissions(
  1. FPDF_DOCUMENT document
)

Function: FPDF_GetDocUserPermissions Get user file permission flags of the document. Parameters: document - Handle to a document. Returned by FPDF_LoadDocument. Return value: A 32-bit integer indicating permission flags. Please refer to the PDF Reference for detailed descriptions. If the document is not protected, 0xffffffff will be returned. Always returns user permissions, even if the document was unlocked by the owner.

Implementation

@ffi.Native<ffi.UnsignedLong Function(FPDF_DOCUMENT)>()
external int FPDF_GetDocUserPermissions(FPDF_DOCUMENT document);