FPDF_MovePages function
- @Native<FPDF_BOOL Function(FPDF_DOCUMENT, Pointer<
Int> , UnsignedLong, Int)>(FPDF_DOCUMENT, ffi.Pointer<ffi.Int>, ffi.UnsignedLong, ffi.Int)>()
- FPDF_DOCUMENT document,
- Pointer<
Int> page_indices, - int page_indices_len,
- int dest_page_index,
Experimental API. Move the given pages to a new index position.
page_indices - the ordered list of pages to move. No duplicates allowed. page_indices_len - the number of elements in |page_indices| dest_page_index - the new index position to which the pages in |page_indices| are moved.
Returns TRUE on success. If it returns FALSE, the document may be left in an indeterminate state.
Example: The PDF document starts out with pages A, B, C, D, with indices
0, 1, 2, 3.
Move(doc,
3, 2, 2, 1); // returns true // The document has pagesA, D, C, B.Move(doc,
0, 4, 3, 3, 1); // returns false // Returned false because index 4 is out of range.Move(doc,
0, 3, 1, 3, 2); // returns false // Returned false because index 2 is out of range for 3 page indices.Move(doc,
2, 2, 2, 0); // returns false // Returned false because2, 2contains duplicates.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_DOCUMENT,
ffi.Pointer<ffi.Int>,
ffi.UnsignedLong,
ffi.Int,
)
>()
external int FPDF_MovePages(
FPDF_DOCUMENT document,
ffi.Pointer<ffi.Int> page_indices,
int page_indices_len,
int dest_page_index,
);