FPDF_RemoveFormFieldHighlight function

  1. @Native<Void Function(FPDF_FORMHANDLE)>(FPDF_FORMHANDLE)>()
void FPDF_RemoveFormFieldHighlight(
  1. FPDF_FORMHANDLE hHandle
)

Function: FPDF_RemoveFormFieldHighlight Remove the form field highlight color in the document. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None. Comments: Please refresh the client window to remove the highlight immediately if necessary.

Implementation

@ffi.Native<ffi.Void Function(FPDF_FORMHANDLE)>()
external void FPDF_RemoveFormFieldHighlight(FPDF_FORMHANDLE hHandle);