FPDF_RenderPageBitmap function

  1. @Native<Void Function(FPDF_BITMAP, FPDF_PAGE, Int, Int, Int, Int, Int, Int)>(FPDF_BITMAP, FPDF_PAGE, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int)>()
void FPDF_RenderPageBitmap(
  1. FPDF_BITMAP bitmap,
  2. FPDF_PAGE page,
  3. int start_x,
  4. int start_y,
  5. int size_x,
  6. int size_y,
  7. int rotate,
  8. int flags,
)

Function: FPDF_RenderPageBitmap Render contents of a page to a device independent bitmap. Parameters: bitmap - Handle to the device independent bitmap (as the output buffer). The bitmap handle can be created by FPDFBitmap_Create or retrieved from an image object by FPDFImageObj_GetBitmap. page - Handle to the page. Returned by FPDF_LoadPage start_x - Left pixel position of the display area in bitmap coordinates. start_y - Top pixel position of the display area in bitmap coordinates. size_x - Horizontal size (in pixels) for displaying the page. size_y - Vertical size (in pixels) for displaying the page. rotate - Page orientation: 0 (normal) 1 (rotated 90 degrees clockwise) 2 (rotated 180 degrees) 3 (rotated 90 degrees counter-clockwise) flags - 0 for normal display, or combination of the Page Rendering flags defined above. With the FPDF_ANNOT flag, it renders all annotations that do not require user-interaction, which are all annotations except widget and popup annotations. Return value: None.

Implementation

@ffi.Native<
  ffi.Void Function(
    FPDF_BITMAP,
    FPDF_PAGE,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
  )
>()
external void FPDF_RenderPageBitmap(
  FPDF_BITMAP bitmap,
  FPDF_PAGE page,
  int start_x,
  int start_y,
  int size_x,
  int size_y,
  int rotate,
  int flags,
);