FPDF_RenderPageBitmap_Start function

  1. @Native<Int Function(FPDF_BITMAP, FPDF_PAGE, Int, Int, Int, Int, Int, Int, Pointer<IFSDK_PAUSE>)>(FPDF_BITMAP, FPDF_PAGE, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Pointer<IFSDK_PAUSE>)>()
int FPDF_RenderPageBitmap_Start(
  1. FPDF_BITMAP bitmap,
  2. FPDF_PAGE page,
  3. int start_x,
  4. int start_y,
  5. int size_x,
  6. int size_y,
  7. int rotate,
  8. int flags,
  9. Pointer<IFSDK_PAUSE> pause,
)

Function: FPDF_RenderPageBitmap_Start Start to render page contents to a device independent bitmap progressively. Parameters: bitmap - Handle to the device independent bitmap (as the output buffer). Bitmap handle can be created by FPDFBitmap_Create(). page - Handle to the page, as returned by FPDF_LoadPage(). start_x - Left pixel position of the display area in the bitmap coordinates. start_y - Top pixel position of the display area in the bitmap coordinates. size_x - Horizontal size (in pixels) for displaying the page. size_y - Vertical size (in pixels) for displaying the page. rotate - Page orientation: 0 (normal), 1 (rotated 90 degrees clockwise), 2 (rotated 180 degrees), 3 (rotated 90 degrees counter-clockwise). flags - 0 for normal display, or combination of flags defined in fpdfview.h. With FPDF_ANNOT flag, it renders all annotations that does not require user-interaction, which are all annotations except widget and popup annotations. pause - The IFSDK_PAUSE interface.A callback mechanism allowing the page rendering process Return value: Rendering Status. See flags for progressive process status for the details.

Implementation

@ffi.Native<
  ffi.Int Function(
    FPDF_BITMAP,
    FPDF_PAGE,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Pointer<IFSDK_PAUSE>,
  )
>()
external int FPDF_RenderPageBitmap_Start(
  FPDF_BITMAP bitmap,
  FPDF_PAGE page,
  int start_x,
  int start_y,
  int size_x,
  int size_y,
  int rotate,
  int flags,
  ffi.Pointer<IFSDK_PAUSE> pause,
);