FPDF_RenderPage_Continue function

  1. @Native<Int Function(FPDF_PAGE, Pointer<IFSDK_PAUSE>)>(FPDF_PAGE, ffi.Pointer<IFSDK_PAUSE>)>()
int FPDF_RenderPage_Continue(
  1. FPDF_PAGE page,
  2. Pointer<IFSDK_PAUSE> pause
)

Function: FPDF_RenderPage_Continue Continue rendering a PDF page. Parameters: page - Handle to the page, as returned by FPDF_LoadPage(). pause - The IFSDK_PAUSE interface (a callback mechanism allowing the page rendering process to be paused before it's finished). This can be NULL if you don't want to pause. Return value: The rendering status. See flags for progressive process status for the details.

Implementation

@ffi.Native<ffi.Int Function(FPDF_PAGE, ffi.Pointer<IFSDK_PAUSE>)>()
external int FPDF_RenderPage_Continue(
  FPDF_PAGE page,
  ffi.Pointer<IFSDK_PAUSE> pause,
);