FPDF_STRING typedef
For Windows programmers: In most cases it's OK to treat FPDF_WIDESTRING as a Windows unicode string, however, special care needs to be taken if you expect to process Unicode larger than 0xffff.
For Linux/Unix programmers: most compiler/library environments use 4 bytes for a Unicode character, and you have to convert between FPDF_WIDESTRING and system wide string by yourself.
Implementation
typedef FPDF_STRING = ffi.Pointer<ffi.Char>;