FPDF_SetFormFieldHighlightAlpha function

  1. @Native<Void Function(FPDF_FORMHANDLE, UnsignedChar)>(FPDF_FORMHANDLE, ffi.UnsignedChar)>()
void FPDF_SetFormFieldHighlightAlpha(
  1. FPDF_FORMHANDLE hHandle,
  2. int alpha
)

Function: FPDF_SetFormFieldHighlightAlpha Set the transparency of the form field highlight color in the document. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). doc - Handle to the document, as returaned by FPDF_LoadDocument(). alpha - The transparency of the form field highlight color, between 0-255. Return Value: None.

Implementation

@ffi.Native<ffi.Void Function(FPDF_FORMHANDLE, ffi.UnsignedChar)>()
external void FPDF_SetFormFieldHighlightAlpha(
  FPDF_FORMHANDLE hHandle,
  int alpha,
);