FPDF_StructElement_Attr_GetName function

  1. @Native<FPDF_BOOL Function(FPDF_STRUCTELEMENT_ATTR, Int, Pointer<Void>, UnsignedLong, Pointer<UnsignedLong>)>(FPDF_STRUCTELEMENT_ATTR, ffi.Int, ffi.Pointer<ffi.Void>, ffi.UnsignedLong, ffi.Pointer<ffi.UnsignedLong>)>()
int FPDF_StructElement_Attr_GetName(
  1. FPDF_STRUCTELEMENT_ATTR struct_attribute,
  2. int index,
  3. Pointer<Void> buffer,
  4. int buflen,
  5. Pointer<UnsignedLong> out_buflen,
)

Experimental API. Function: FPDF_StructElement_Attr_GetName Get the name of an attribute in a structure element attribute map. Parameters: struct_attribute - Handle to the struct element attribute. index - The index of attribute in the map. buffer - A buffer for output. May be NULL. This is only modified if |buflen| is longer than the length of the key. Optional, pass null to just retrieve the size of the buffer needed. buflen - The length of the buffer. out_buflen - A pointer to variable that will receive the minimum buffer size to contain the key. Not filled if FALSE is returned. Return value: TRUE if the operation was successful, FALSE otherwise.

Implementation

@ffi.Native<
  FPDF_BOOL Function(
    FPDF_STRUCTELEMENT_ATTR,
    ffi.Int,
    ffi.Pointer<ffi.Void>,
    ffi.UnsignedLong,
    ffi.Pointer<ffi.UnsignedLong>,
  )
>()
external int FPDF_StructElement_Attr_GetName(
  FPDF_STRUCTELEMENT_ATTR struct_attribute,
  int index,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
  ffi.Pointer<ffi.UnsignedLong> out_buflen,
);