FPDF_StructElement_Attr_GetNumberValue function

  1. @Native<FPDF_BOOL Function(FPDF_STRUCTELEMENT_ATTR_VALUE, Pointer<Float>)>(FPDF_STRUCTELEMENT_ATTR_VALUE, ffi.Pointer<ffi.Float>)>()
int FPDF_StructElement_Attr_GetNumberValue(
  1. FPDF_STRUCTELEMENT_ATTR_VALUE value,
  2. Pointer<Float> out_value
)

Experimental API. Function: FPDF_StructElement_Attr_GetNumberValue Get the value of a number attribute in an attribute map as float. FPDF_StructElement_Attr_GetType() should have returned FPDF_OBJECT_NUMBER for this property. Parameters: value - Handle to the value. out_value - A pointer to variable that will receive the value. Not filled if false is returned. Return value: Returns TRUE if the attribute maps to a number value, FALSE otherwise.

Implementation

@ffi.Native<
  FPDF_BOOL Function(FPDF_STRUCTELEMENT_ATTR_VALUE, ffi.Pointer<ffi.Float>)
>()
external int FPDF_StructElement_Attr_GetNumberValue(
  FPDF_STRUCTELEMENT_ATTR_VALUE value,
  ffi.Pointer<ffi.Float> out_value,
);