FPDF_StructElement_Attr_GetStringValue function
- @Native<FPDF_BOOL Function(FPDF_STRUCTELEMENT_ATTR_VALUE, Pointer<
Void> , UnsignedLong, Pointer<UnsignedLong> )>(FPDF_STRUCTELEMENT_ATTR_VALUE, ffi.Pointer<ffi.Void>, ffi.UnsignedLong, ffi.Pointer<ffi.UnsignedLong>)>()
- FPDF_STRUCTELEMENT_ATTR_VALUE value,
- Pointer<
Void> buffer, - int buflen,
- Pointer<
UnsignedLong> out_buflen,
Experimental API. Function: FPDF_StructElement_Attr_GetStringValue Get the value of a string attribute in an attribute map as string. FPDF_StructElement_Attr_GetType() should have returned FPDF_OBJECT_STRING or FPDF_OBJECT_NAME for this property. Parameters: value - Handle to the value. buffer - A buffer for holding the returned key in UTF-16LE. This is only modified if |buflen| is longer than the length of the key. Optional, pass null to just retrieve the size of the buffer needed. buflen - The length of the buffer. out_buflen - A pointer to variable that will receive the minimum buffer size to contain the key. Not filled if FALSE is returned. Return value: Returns TRUE if the attribute maps to a string value, FALSE otherwise.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_STRUCTELEMENT_ATTR_VALUE,
ffi.Pointer<ffi.Void>,
ffi.UnsignedLong,
ffi.Pointer<ffi.UnsignedLong>,
)
>()
external int FPDF_StructElement_Attr_GetStringValue(
FPDF_STRUCTELEMENT_ATTR_VALUE value,
ffi.Pointer<ffi.Void> buffer,
int buflen,
ffi.Pointer<ffi.UnsignedLong> out_buflen,
);