FPDF_StructElement_Attr_GetValue function

  1. @Native<FPDF_STRUCTELEMENT_ATTR_VALUE Function(FPDF_STRUCTELEMENT_ATTR struct_attribute, FPDF_BYTESTRING name)>(FPDF_STRUCTELEMENT_ATTR, FPDF_BYTESTRING)>()
FPDF_STRUCTELEMENT_ATTR_VALUE FPDF_StructElement_Attr_GetValue(
  1. FPDF_STRUCTELEMENT_ATTR struct_attribute,
  2. FPDF_BYTESTRING name
)

Experimental API. Function: FPDF_StructElement_Attr_GetValue Get a handle to a value for an attribute in a structure element attribute map. Parameters: struct_attribute - Handle to the struct element attribute. name - The attribute name. Return value: Returns a handle to the value associated with the input, if any. Returns NULL on failure. The caller does not own the handle. The handle remains valid as long as |struct_attribute| remains valid.

Implementation

@ffi.Native<
  FPDF_STRUCTELEMENT_ATTR_VALUE Function(
    FPDF_STRUCTELEMENT_ATTR,
    FPDF_BYTESTRING,
  )
>()
external FPDF_STRUCTELEMENT_ATTR_VALUE FPDF_StructElement_Attr_GetValue(
  FPDF_STRUCTELEMENT_ATTR struct_attribute,
  FPDF_BYTESTRING name,
);