FPDF_StructElement_GetTitle function

  1. @Native<UnsignedLong Function(FPDF_STRUCTELEMENT, Pointer<Void>, UnsignedLong)>(FPDF_STRUCTELEMENT, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)>()
int FPDF_StructElement_GetTitle(
  1. FPDF_STRUCTELEMENT struct_element,
  2. Pointer<Void> buffer,
  3. int buflen
)

Function: FPDF_StructElement_GetTitle Get the title (/T) for a given element. Parameters: struct_element - Handle to the struct element. buffer - A buffer for output. May be NULL. buflen - The length of the buffer, in bytes. May be 0. Return value: The number of bytes in the title, including the terminating NUL character. The number of bytes is returned regardless of the |buffer| and |buflen| parameters. Comments: Regardless of the platform, the |buffer| is always in UTF-16LE encoding. The string is terminated by a UTF16 NUL character. If |buflen| is less than the required length, or |buffer| is NULL, |buffer| will not be modified.

Implementation

@ffi.Native<
  ffi.UnsignedLong Function(
    FPDF_STRUCTELEMENT,
    ffi.Pointer<ffi.Void>,
    ffi.UnsignedLong,
  )
>()
external int FPDF_StructElement_GetTitle(
  FPDF_STRUCTELEMENT struct_element,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
);