FPDF_StructTree_CountChildren function

  1. @Native<Int Function(FPDF_STRUCTTREE)>(FPDF_STRUCTTREE)>()
int FPDF_StructTree_CountChildren(
  1. FPDF_STRUCTTREE struct_tree
)

Function: FPDF_StructTree_CountChildren Count the number of children for the structure tree. Parameters: struct_tree - Handle to the structure tree, as returned by FPDF_StructTree_LoadPage(). Return value: The number of children, or -1 on error.

Implementation

@ffi.Native<ffi.Int Function(FPDF_STRUCTTREE)>()
external int FPDF_StructTree_CountChildren(FPDF_STRUCTTREE struct_tree);