FWL_EVENTFLAG enum
Key flags.
Values
- FWL_EVENTFLAG_ShiftKey → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(1) - FWL_EVENTFLAG_ControlKey → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(2) - FWL_EVENTFLAG_AltKey → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(4) - FWL_EVENTFLAG_MetaKey → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(8) - FWL_EVENTFLAG_KeyPad → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(16) - FWL_EVENTFLAG_AutoRepeat → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(32) - FWL_EVENTFLAG_LeftButtonDown → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(64) - FWL_EVENTFLAG_MiddleButtonDown → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(128) - FWL_EVENTFLAG_RightButtonDown → const FWL_EVENTFLAG
-
const FWL_EVENTFLAG(256)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → FWL_EVENTFLAG
Constants
-
values
→ const List<
FWL_EVENTFLAG> - A constant List of the values in this enum, in order of their declaration.