FORM_CanRedo method

int FORM_CanRedo(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page
)

Function: FORM_CanRedo Find out if it is possible for the current focused widget in a given form to perform a redo operation. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). Return Value: True if it is possible to redo.

Implementation

int FORM_CanRedo(FPDF_FORMHANDLE hHandle, FPDF_PAGE page) {
  return _FORM_CanRedo(hHandle, page);
}