FORM_DoDocumentAAction method
Function: FORM_DoDocumentAAction This method is required for performing the document's additional-action. Parameters: hHandle - Handle to the form fill module. Returned by FPDFDOC_InitFormFillEnvironment. aaType - The type of the additional-actions which defined above. Return Value: None. Comments: This method will do nothing if there is no document additional-action corresponding to the specified |aaType|.
Implementation
void FORM_DoDocumentAAction(FPDF_FORMHANDLE hHandle, int aaType) {
return _FORM_DoDocumentAAction(hHandle, aaType);
}