FORM_DoDocumentJSAction method

void FORM_DoDocumentJSAction(
  1. FPDF_FORMHANDLE hHandle
)

Function: FORM_DoDocumentJSAction This method is required for performing document-level JavaScript actions. It should be invoked after the PDF document has been loaded. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None. Comments: If there is document-level JavaScript action embedded in the document, this method will execute the JavaScript action. Otherwise, the method will do nothing.

Implementation

void FORM_DoDocumentJSAction(FPDF_FORMHANDLE hHandle) {
  return _FORM_DoDocumentJSAction(hHandle);
}