FORM_DoDocumentOpenAction method

void FORM_DoDocumentOpenAction(
  1. FPDF_FORMHANDLE hHandle
)

Function: FORM_DoDocumentOpenAction This method is required for performing open-action when the document is opened. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None. Comments: This method will do nothing if there are no open-actions embedded in the document.

Implementation

void FORM_DoDocumentOpenAction(FPDF_FORMHANDLE hHandle) {
  return _FORM_DoDocumentOpenAction(hHandle);
}