FORM_GetSelectedText method

int FORM_GetSelectedText(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. Pointer<Void> buffer,
  4. int buflen,
)

Function: FORM_GetSelectedText Call this function to obtain selected text within a form text field or form combobox text field. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). buffer - Buffer for holding the selected text, encoded in UTF-16LE. If NULL, |buffer| is not modified. buflen - Length of |buffer| in bytes. If |buflen| is less than the length of the selected text string, |buffer| is not modified. Return Value: Length in bytes of selected text in form text field or form combobox text field.

Implementation

int FORM_GetSelectedText(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
) {
  return _FORM_GetSelectedText(hHandle, page, buffer, buflen);
}