FORM_OnAfterLoadPage method

void FORM_OnAfterLoadPage(
  1. FPDF_PAGE page,
  2. FPDF_FORMHANDLE hHandle
)

Function: FORM_OnAfterLoadPage This method is required for implementing all the form related functions. Should be invoked after user successfully loaded a PDF page, and FPDFDOC_InitFormFillEnvironment() has been invoked. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None.

Implementation

void FORM_OnAfterLoadPage(FPDF_PAGE page, FPDF_FORMHANDLE hHandle) {
  return _FORM_OnAfterLoadPage(page, hHandle);
}