FORM_OnBeforeClosePage method
Function: FORM_OnBeforeClosePage This method is required for implementing all the form related functions. Should be invoked before user closes the PDF page. Parameters: page - Handle to the page, as returned by FPDF_LoadPage(). hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None.
Implementation
void FORM_OnBeforeClosePage(FPDF_PAGE page, FPDF_FORMHANDLE hHandle) {
return _FORM_OnBeforeClosePage(page, hHandle);
}