FORM_OnFocus method

int FORM_OnFocus(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. int modifier,
  4. double page_x,
  5. double page_y,
)

Function: FORM_OnFocus This function focuses the form annotation at a given point. If the annotation at the point already has focus, nothing happens. If there is no annotation at the point, removes form focus. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). modifier - Indicates whether various virtual keys are down. page_x - Specifies the x-coordinate of the cursor in PDF user space. page_y - Specifies the y-coordinate of the cursor in PDF user space. Return Value: True if there is an annotation at the given point and it has focus.

Implementation

int FORM_OnFocus(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  int modifier,
  double page_x,
  double page_y,
) {
  return _FORM_OnFocus(hHandle, page, modifier, page_x, page_y);
}