FORM_OnKeyUp method
Function: FORM_OnKeyUp Call this member function when a nonsystem key is released. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). nKeyCode - The virtual-key code of the given key (see fpdf_fwlevent.h for virtual key codes). modifier - Mask of key flags (see fpdf_fwlevent.h for key flag values). Return Value: True indicates success; otherwise false. Comments: Currently unimplemented and always returns false. PDFium reserves this API and may implement it in the future on an as-needed basis.
Implementation
int FORM_OnKeyUp(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int nKeyCode,
int modifier,
) {
return _FORM_OnKeyUp(hHandle, page, nKeyCode, modifier);
}