FORM_OnLButtonDoubleClick method
int
FORM_OnLButtonDoubleClick(
- FPDF_FORMHANDLE hHandle,
- FPDF_PAGE page,
- int modifier,
- double page_x,
- double page_y,
Function: FORM_OnLButtonDoubleClick Call this member function when the user double clicks the left mouse button. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). modifier - Indicates whether various virtual keys are down. page_x - Specifies the x-coordinate of the cursor in PDF user space. page_y - Specifies the y-coordinate of the cursor in PDF user space. Return Value: True indicates success; otherwise false.
Implementation
int FORM_OnLButtonDoubleClick(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int modifier,
double page_x,
double page_y,
) {
return _FORM_OnLButtonDoubleClick(hHandle, page, modifier, page_x, page_y);
}