FORM_OnLButtonUp method

int FORM_OnLButtonUp(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. int modifier,
  4. double page_x,
  5. double page_y,
)

Function: FORM_OnLButtonUp Call this member function when the user releases the left mouse button. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). modifier - Indicates whether various virtual keys are down. page_x - Specifies the x-coordinate of the cursor in device. page_y - Specifies the y-coordinate of the cursor in device. Return Value: True indicates success; otherwise false.

Implementation

int FORM_OnLButtonUp(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  int modifier,
  double page_x,
  double page_y,
) {
  return _FORM_OnLButtonUp(hHandle, page, modifier, page_x, page_y);
}