FORM_OnMouseMove method

int FORM_OnMouseMove(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. int modifier,
  4. double page_x,
  5. double page_y,
)

Function: FORM_OnMouseMove Call this member function when the mouse cursor moves. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). modifier - Indicates whether various virtual keys are down. page_x - Specifies the x-coordinate of the cursor in PDF user space. page_y - Specifies the y-coordinate of the cursor in PDF user space. Return Value: True indicates success; otherwise false.

Implementation

int FORM_OnMouseMove(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  int modifier,
  double page_x,
  double page_y,
) {
  return _FORM_OnMouseMove(hHandle, page, modifier, page_x, page_y);
}