FORM_Redo method
Function: FORM_Redo Make the current focused widget perform a redo operation. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). Return Value: True if the redo operation succeeded.
Implementation
int FORM_Redo(FPDF_FORMHANDLE hHandle, FPDF_PAGE page) {
return _FORM_Redo(hHandle, page);
}