FORM_SetFocusedAnnot method

int FORM_SetFocusedAnnot(
  1. FPDF_FORMHANDLE handle,
  2. FPDF_ANNOTATION annot
)

Experimental API. Function: FORM_SetFocusedAnnot. Call this member function to set the currently focused annotation. Parameters: handle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). annot - Handle to an annotation. Return Value: True indicates success; otherwise false. Comments: |annot| can't be NULL. To kill focus, use FORM_ForceToKillFocus() instead.

Implementation

int FORM_SetFocusedAnnot(FPDF_FORMHANDLE handle, FPDF_ANNOTATION annot) {
  return _FORM_SetFocusedAnnot(handle, annot);
}