FORM_SetIndexSelected method
Experimental API Function: FORM_SetIndexSelected Selects/deselects the value at the given |index| of the focused annotation. Parameters: hHandle - Handle to the form fill module. Returned by FPDFDOC_InitFormFillEnvironment. page - Handle to the page. Returned by FPDF_LoadPage index - 0-based index of value to be set as selected/unselected selected - true to select, false to deselect Return Value: TRUE if the operation succeeded. FALSE if the operation failed or widget is not a supported type. Comments: Intended for use with listbox/combobox widget types. Comboboxes have at most a single value selected at a time which cannot be deselected. Deselect on a combobox is a no-op that returns false. Default implementation is a no-op that will return false for other types. Not currently supported for XFA forms - will return false.
Implementation
int FORM_SetIndexSelected(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int index,
int selected,
) {
return _FORM_SetIndexSelected(hHandle, page, index, selected);
}