FPDFAnnot_AddInkStroke method
Experimental API. Add a new InkStroke, represented by an array of points, to the InkList of |annot|. The API creates an InkList if one doesn't already exist in |annot|. This API works only for ink annotations. Please refer to ISO 32000-1:2008 spec, section 12.5.6.13.
annot - handle to an annotation. points - pointer to a FS_POINTF array representing input points. point_count - number of elements in |points| array. This should not exceed the maximum value that can be represented by an int32_t).
Returns the 0-based index at which the new InkStroke is added in the InkList of the |annot|. Returns -1 on failure.
Implementation
int FPDFAnnot_AddInkStroke(
FPDF_ANNOTATION annot,
ffi.Pointer<FS_POINTF> points,
int point_count,
) {
return _FPDFAnnot_AddInkStroke(annot, points, point_count);
}