FPDFAnnot_AppendAttachmentPoints method

int FPDFAnnot_AppendAttachmentPoints(
  1. FPDF_ANNOTATION annot,
  2. Pointer<FS_QUADPOINTSF> quad_points
)

Experimental API. Append to the list of attachment points (i.e. quadpoints) of an annotation. If the annotation's appearance stream is defined and this annotation is of a type with quadpoints, then update the bounding box too if the new quadpoints define a bigger one.

annot - handle to an annotation. quad_points - the quadpoints to be set.

Returns true if successful.

Implementation

int FPDFAnnot_AppendAttachmentPoints(
  FPDF_ANNOTATION annot,
  ffi.Pointer<FS_QUADPOINTSF> quad_points,
) {
  return _FPDFAnnot_AppendAttachmentPoints(annot, quad_points);
}