FPDFAnnot_AppendObject method
Experimental API. Add |obj| to |annot|. |obj| must have been created by FPDFPageObj_CreateNew{Path|Rect}() or FPDFPageObj_New{Text|Image}Obj(), and will be owned by |annot|. Note that an |obj| cannot belong to more than one |annot|. Currently, only ink and stamp annotations are supported by this API. Also note that only path, image, and text objects have APIs for creation.
annot - handle to an annotation. obj - handle to the object that is to be added to |annot|.
Return true if successful.
Implementation
int FPDFAnnot_AppendObject(FPDF_ANNOTATION annot, FPDF_PAGEOBJECT obj) {
return _FPDFAnnot_AppendObject(annot, obj);
}