FPDFAnnot_CountAttachmentPoints method

int FPDFAnnot_CountAttachmentPoints(
  1. FPDF_ANNOTATION annot
)

Experimental API. Get the number of sets of quadpoints of an annotation.

annot - handle to an annotation.

Returns the number of sets of quadpoints, or 0 on failure.

Implementation

int FPDFAnnot_CountAttachmentPoints(FPDF_ANNOTATION annot) {
  return _FPDFAnnot_CountAttachmentPoints(annot);
}