FPDFAnnot_GetBorder method

int FPDFAnnot_GetBorder(
  1. FPDF_ANNOTATION annot,
  2. Pointer<Float> horizontal_radius,
  3. Pointer<Float> vertical_radius,
  4. Pointer<Float> border_width,
)

Experimental API. Get the characteristics of the annotation's border (rounded rectangle).

annot - handle to an annotation horizontal_radius - horizontal corner radius, in default user space units vertical_radius - vertical corner radius, in default user space units border_width - border width, in default user space units

Returns true if |horizontal_radius|, |vertical_radius| and |border_width| are not NULL, false otherwise.

Implementation

int FPDFAnnot_GetBorder(
  FPDF_ANNOTATION annot,
  ffi.Pointer<ffi.Float> horizontal_radius,
  ffi.Pointer<ffi.Float> vertical_radius,
  ffi.Pointer<ffi.Float> border_width,
) {
  return _FPDFAnnot_GetBorder(
    annot,
    horizontal_radius,
    vertical_radius,
    border_width,
  );
}