FPDFAnnot_GetFormControlIndex method
Experimental API. Gets the index of |annot| in |annot|'s control group. A group of interactive form annotations is collectively called a form control group. Here, |annot|, an interactive form annotation, should be either a radio button or a checkbox.
hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation.
Returns index of a given |annot| in its control group or -1 on error.
Implementation
int FPDFAnnot_GetFormControlIndex(
FPDF_FORMHANDLE hHandle,
FPDF_ANNOTATION annot,
) {
return _FPDFAnnot_GetFormControlIndex(hHandle, annot);
}