FPDFAnnot_HasAttachmentPoints method

int FPDFAnnot_HasAttachmentPoints(
  1. FPDF_ANNOTATION annot
)

Experimental API. Check if the annotation is of a type that has attachment points (i.e. quadpoints). Quadpoints are the vertices of the rectangle that encompasses the texts affected by the annotation. They provide the coordinates in the page where the annotation is attached. Only text markup annotations (i.e. highlight, strikeout, squiggly, and underline) and link annotations have quadpoints.

annot - handle to an annotation.

Returns true if the annotation is of a type that has quadpoints, false otherwise.

Implementation

int FPDFAnnot_HasAttachmentPoints(FPDF_ANNOTATION annot) {
  return _FPDFAnnot_HasAttachmentPoints(annot);
}