FPDFAnnot_IsOptionSelected method

int FPDFAnnot_IsOptionSelected(
  1. FPDF_FORMHANDLE handle,
  2. FPDF_ANNOTATION annot,
  3. int index
)

Experimental API. Determine whether or not the option at |index| in |annot|'s "Opt" dictionary is selected. Intended for use with listbox and combobox widget annotations.

handle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation. index - numeric index of the option in the "Opt" array.

Returns true if the option at |index| in |annot|'s "Opt" dictionary is selected, false otherwise.

Implementation

int FPDFAnnot_IsOptionSelected(
  FPDF_FORMHANDLE handle,
  FPDF_ANNOTATION annot,
  int index,
) {
  return _FPDFAnnot_IsOptionSelected(handle, annot, index);
}