FPDFAnnot_SetRect method
Experimental API. Set the annotation rectangle defining the location of the annotation. If the annotation's appearance stream is defined and this annotation is of a type without quadpoints, then update the bounding box too if the new rectangle defines a bigger one.
annot - handle to an annotation. rect - the annotation rectangle to be set.
Returns true if successful.
Implementation
int FPDFAnnot_SetRect(FPDF_ANNOTATION annot, ffi.Pointer<FS_RECTF> rect) {
return _FPDFAnnot_SetRect(annot, rect);
}