FPDFAnnot_SetStringValue method

int FPDFAnnot_SetStringValue(
  1. FPDF_ANNOTATION annot,
  2. FPDF_BYTESTRING key,
  3. FPDF_WIDESTRING value
)

Experimental API. Set the string value corresponding to |key| in |annot|'s dictionary, overwriting the existing value if any. The value type would be FPDF_OBJECT_STRING after this function call succeeds.

annot - handle to an annotation. key - the key to the dictionary entry to be set, encoded in UTF-8. value - the string value to be set, encoded in UTF-16LE.

Returns true if successful.

Implementation

int FPDFAnnot_SetStringValue(
  FPDF_ANNOTATION annot,
  FPDF_BYTESTRING key,
  FPDF_WIDESTRING value,
) {
  return _FPDFAnnot_SetStringValue(annot, key, value);
}