FPDFAttachment_GetName method

int FPDFAttachment_GetName(
  1. FPDF_ATTACHMENT attachment,
  2. Pointer<FPDF_WCHAR> buffer,
  3. int buflen
)

Experimental API. Get the name of the |attachment| file. |buffer| is only modified if |buflen| is longer than the length of the file name. On errors, |buffer| is unmodified and the returned length is 0.

attachment - handle to an attachment. buffer - buffer for holding the file name, encoded in UTF-16LE. buflen - length of the buffer in bytes.

Returns the length of the file name in bytes.

Implementation

int FPDFAttachment_GetName(
  FPDF_ATTACHMENT attachment,
  ffi.Pointer<FPDF_WCHAR> buffer,
  int buflen,
) {
  return _FPDFAttachment_GetName(attachment, buffer, buflen);
}