FPDFAvail_Create method
Create a document availability provider.
file_avail - pointer to file availability interface. file - pointer to a file access interface.
Returns a handle to the document availability provider, or NULL on error.
FPDFAvail_Destroy() must be called when done with the availability provider.
Implementation
FPDF_AVAIL FPDFAvail_Create(
ffi.Pointer<FX_FILEAVAIL> file_avail,
ffi.Pointer<FPDF_FILEACCESS> file,
) {
return _FPDFAvail_Create(file_avail, file);
}