FPDFBookmark_GetAction method
Get the action associated with |bookmark|.
bookmark - handle to the bookmark.
Returns the handle to the action data, or NULL if no action is associated with |bookmark|. If this function returns a valid handle, it is valid as long as |bookmark| is valid. If this function returns NULL, FPDFBookmark_GetDest() should be called to get the |bookmark| destination data.
Implementation
FPDF_ACTION FPDFBookmark_GetAction(FPDF_BOOKMARK bookmark) {
return _FPDFBookmark_GetAction(bookmark);
}