FPDFBookmark_GetCount method
Experimental API. Get the number of chlidren of |bookmark|.
bookmark - handle to the bookmark.
Returns a signed integer that represents the number of sub-items the given bookmark has. If the value is positive, child items shall be shown by default (open state). If the value is negative, child items shall be hidden by default (closed state). Please refer to PDF 32000-1:2008, Table 153. Returns 0 if the bookmark has no children or is invalid.
Implementation
int FPDFBookmark_GetCount(FPDF_BOOKMARK bookmark) {
return _FPDFBookmark_GetCount(bookmark);
}