FPDFBookmark_GetNextSibling method

FPDF_BOOKMARK FPDFBookmark_GetNextSibling(
  1. FPDF_DOCUMENT document,
  2. FPDF_BOOKMARK bookmark
)

Get the next sibling of |bookmark|.

document - handle to the document. bookmark - handle to the current bookmark.

Returns a handle to the next sibling of |bookmark|, or NULL if this is the last bookmark at this level.

Note that the caller is responsible for handling circular bookmark references, as may arise from malformed documents.

Implementation

FPDF_BOOKMARK FPDFBookmark_GetNextSibling(
  FPDF_DOCUMENT document,
  FPDF_BOOKMARK bookmark,
) {
  return _FPDFBookmark_GetNextSibling(document, bookmark);
}