FPDFBookmark_GetTitle method

int FPDFBookmark_GetTitle(
  1. FPDF_BOOKMARK bookmark,
  2. Pointer<Void> buffer,
  3. int buflen
)

Get the title of |bookmark|.

bookmark - handle to the bookmark. buffer - buffer for the title. May be NULL. buflen - the length of the buffer in bytes. May be 0.

Returns the number of bytes in the title, including the terminating NUL character. The number of bytes is returned regardless of the |buffer| and |buflen| parameters.

Regardless of the platform, the |buffer| is always in UTF-16LE encoding. The string is terminated by a UTF16 NUL character. If |buflen| is less than the required length, or |buffer| is NULL, |buffer| will not be modified.

Implementation

int FPDFBookmark_GetTitle(
  FPDF_BOOKMARK bookmark,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
) {
  return _FPDFBookmark_GetTitle(bookmark, buffer, buflen);
}