FPDFDest_GetLocationInPage method
Get the (x, y, zoom) location of |dest| in the destination page, if the
destination is in page /XYZ x y zoom syntax.
dest - handle to the destination. hasXVal - out parameter; true if the x value is not null hasYVal - out parameter; true if the y value is not null hasZoomVal - out parameter; true if the zoom value is not null x - out parameter; the x coordinate, in page coordinates. y - out parameter; the y coordinate, in page coordinates. zoom - out parameter; the zoom value. Returns TRUE on successfully reading the /XYZ value.
Note the x, y, zoom values are only set if the corresponding hasXVal,
hasYVal or hasZoomVal flags are true.
Implementation
int FPDFDest_GetLocationInPage(
FPDF_DEST dest,
ffi.Pointer<FPDF_BOOL> hasXVal,
ffi.Pointer<FPDF_BOOL> hasYVal,
ffi.Pointer<FPDF_BOOL> hasZoomVal,
ffi.Pointer<FS_FLOAT> x,
ffi.Pointer<FS_FLOAT> y,
ffi.Pointer<FS_FLOAT> zoom,
) {
return _FPDFDest_GetLocationInPage(
dest,
hasXVal,
hasYVal,
hasZoomVal,
x,
y,
zoom,
);
}