FPDFDoc_AddAttachment method
Experimental API. Add an embedded file with |name| in |document|. If |name| is empty, or if |name| is the name of a existing embedded file in |document|, or if |document|'s embedded file name tree is too deep (i.e. |document| has too many embedded files already), then a new attachment will not be added.
document - handle to a document. name - name of the new attachment.
Returns a handle to the new attachment object, or NULL on failure.
Implementation
FPDF_ATTACHMENT FPDFDoc_AddAttachment(
FPDF_DOCUMENT document,
FPDF_WIDESTRING name,
) {
return _FPDFDoc_AddAttachment(document, name);
}