FPDFFont_GetBaseFontName method

int FPDFFont_GetBaseFontName(
  1. FPDF_FONT font,
  2. Pointer<Char> buffer,
  3. int length
)

Experimental API. Get the base name of a font.

font - the handle to the font object. buffer - the address of a buffer that receives the base font name. length - the size, in bytes, of |buffer|.

Returns the number of bytes in the base name (including the trailing NUL character) on success, 0 on error. The base name is typically the font's PostScript name. See descriptions of "BaseFont" in ISO 32000-1:2008 spec.

Regardless of the platform, the |buffer| is always in UTF-8 encoding. If |length| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.

Implementation

int FPDFFont_GetBaseFontName(
  FPDF_FONT font,
  ffi.Pointer<ffi.Char> buffer,
  int length,
) {
  return _FPDFFont_GetBaseFontName(font, buffer, length);
}