FPDFImageObj_GetImageDataDecoded method
int
FPDFImageObj_GetImageDataDecoded(
- FPDF_PAGEOBJECT image_object,
- Pointer<
Void> buffer, - int buflen
Get the decoded image data of |image_object|. The decoded data is the uncompressed image data, i.e. the raw image data after having all filters applied. |buffer| is only modified if |buflen| is longer than the length of the decoded image data.
image_object - handle to an image object. buffer - buffer for holding the decoded image data. buflen - length of the buffer in bytes.
Returns the length of the decoded image data.
Implementation
int FPDFImageObj_GetImageDataDecoded(
FPDF_PAGEOBJECT image_object,
ffi.Pointer<ffi.Void> buffer,
int buflen,
) {
return _FPDFImageObj_GetImageDataDecoded(image_object, buffer, buflen);
}