FPDFImageObj_GetImageDataRaw method

int FPDFImageObj_GetImageDataRaw(
  1. FPDF_PAGEOBJECT image_object,
  2. Pointer<Void> buffer,
  3. int buflen
)

Get the raw image data of |image_object|. The raw data is the image data as stored in the PDF without applying any filters. |buffer| is only modified if |buflen| is longer than the length of the raw image data.

image_object - handle to an image object. buffer - buffer for holding the raw image data. buflen - length of the buffer in bytes.

Returns the length of the raw image data.

Implementation

int FPDFImageObj_GetImageDataRaw(
  FPDF_PAGEOBJECT image_object,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
) {
  return _FPDFImageObj_GetImageDataRaw(image_object, buffer, buflen);
}