FPDFLink_CountRects method

int FPDFLink_CountRects(
  1. FPDF_PAGELINK link_page,
  2. int link_index
)

Function: FPDFLink_CountRects Count number of rectangular areas for the link. Parameters: link_page - Handle returned by FPDFLink_LoadWebLinks. link_index - Zero-based index for the link. Return Value: Number of rectangular areas for the link. If |link_index| does not correspond to a valid link, then 0 is returned.

Implementation

int FPDFLink_CountRects(FPDF_PAGELINK link_page, int link_index) {
  return _FPDFLink_CountRects(link_page, link_index);
}