FPDFLink_GetAction method

FPDF_ACTION FPDFLink_GetAction(
  1. FPDF_LINK link
)

Get action info for |link|.

link - handle to the link.

Returns a handle to the action associated to |link|, or NULL if no action. If this function returns a valid handle, it is valid as long as |link| is valid.

Implementation

FPDF_ACTION FPDFLink_GetAction(FPDF_LINK link) {
  return _FPDFLink_GetAction(link);
}