FPDFLink_GetTextRange method

int FPDFLink_GetTextRange(
  1. FPDF_PAGELINK link_page,
  2. int link_index,
  3. Pointer<Int> start_char_index,
  4. Pointer<Int> char_count,
)

Experimental API. Function: FPDFLink_GetTextRange Fetch the start char index and char count for a link. Parameters: link_page - Handle returned by FPDFLink_LoadWebLinks. link_index - Zero-based index for the link. start_char_index - pointer to int receiving the start char index char_count - pointer to int receiving the char count Return Value: On success, return TRUE and fill in |start_char_index| and |char_count|. if |link_page| is invalid or if |link_index| does not correspond to a valid link, then return FALSE and the out parameters remain unmodified.

Implementation

int FPDFLink_GetTextRange(
  FPDF_PAGELINK link_page,
  int link_index,
  ffi.Pointer<ffi.Int> start_char_index,
  ffi.Pointer<ffi.Int> char_count,
) {
  return _FPDFLink_GetTextRange(
    link_page,
    link_index,
    start_char_index,
    char_count,
  );
}