FPDFLink_GetURL method

int FPDFLink_GetURL(
  1. FPDF_PAGELINK link_page,
  2. int link_index,
  3. Pointer<FPDF_WCHAR> buffer,
  4. int buflen,
)

Function: FPDFLink_GetURL Fetch the URL information for a detected web link. Parameters: link_page - Handle returned by FPDFLink_LoadWebLinks. link_index - Zero-based index for the link. buffer - A unicode buffer for the result. buflen - Number of 16-bit code units (not bytes) for the buffer, including an additional terminator. Return Value: If |buffer| is NULL or |buflen| is zero, return the number of 16-bit code units (not bytes) needed to buffer the result (an additional terminator is included in this count). Otherwise, copy the result into |buffer|, truncating at |buflen| if the result is too large to fit, and return the number of 16-bit code units actually copied into the buffer (the additional terminator is also included in this count). If |link_index| does not correspond to a valid link, then the result is an empty string.

Implementation

int FPDFLink_GetURL(
  FPDF_PAGELINK link_page,
  int link_index,
  ffi.Pointer<ffi.UnsignedShort> buffer,
  int buflen,
) {
  return _FPDFLink_GetURL(link_page, link_index, buffer, buflen);
}