FPDFPageObjMark_GetName method

int FPDFPageObjMark_GetName(
  1. FPDF_PAGEOBJECTMARK mark,
  2. Pointer<FPDF_WCHAR> buffer,
  3. int buflen,
  4. Pointer<UnsignedLong> out_buflen,
)

Experimental API. Get the name of a content mark.

mark - handle to a content mark. buffer - buffer for holding the returned name in UTF-16LE. This is only modified if |buflen| is large enough to store the name. Optional, pass null to just retrieve the size of the buffer needed. buflen - length of the buffer in bytes. out_buflen - pointer to variable that will receive the minimum buffer size in bytes to contain the name. This is a required parameter. Not filled if FALSE is returned.

Returns TRUE if the operation succeeded, FALSE if it failed.

Implementation

int FPDFPageObjMark_GetName(
  FPDF_PAGEOBJECTMARK mark,
  ffi.Pointer<FPDF_WCHAR> buffer,
  int buflen,
  ffi.Pointer<ffi.UnsignedLong> out_buflen,
) {
  return _FPDFPageObjMark_GetName(mark, buffer, buflen, out_buflen);
}