FPDFPageObjMark_GetParamFloatValue method

int FPDFPageObjMark_GetParamFloatValue(
  1. FPDF_PAGEOBJECTMARK mark,
  2. FPDF_BYTESTRING key,
  3. Pointer<Float> out_value
)

Experimental API. Get the value of a number property in a content mark by key as float. FPDFPageObjMark_GetParamValueType() should have returned FPDF_OBJECT_NUMBER for this property.

mark - handle to a content mark. key - string key of the property. out_value - pointer to variable that will receive the value. Not filled if false is returned.

Returns TRUE if the key maps to a number value, FALSE otherwise.

Implementation

int FPDFPageObjMark_GetParamFloatValue(
  FPDF_PAGEOBJECTMARK mark,
  FPDF_BYTESTRING key,
  ffi.Pointer<ffi.Float> out_value,
) {
  return _FPDFPageObjMark_GetParamFloatValue(mark, key, out_value);
}