FPDFPageObjMark_GetParamKey method

int FPDFPageObjMark_GetParamKey(
  1. FPDF_PAGEOBJECTMARK mark,
  2. int index,
  3. Pointer<FPDF_WCHAR> buffer,
  4. int buflen,
  5. Pointer<UnsignedLong> out_buflen,
)

Experimental API. Get the key of a property in a content mark.

mark - handle to a content mark. index - index of the property. buffer - buffer for holding the returned key in UTF-16LE. This is only modified if |buflen| is large enough to store the key. Optional, pass null to just retrieve the size of the buffer needed. buflen - length of the buffer in bytes. out_buflen - pointer to variable that will receive the minimum buffer size in bytes to contain the name. This is a required parameter. Not filled if FALSE is returned.

Returns TRUE if the operation was successful, FALSE otherwise.

Implementation

int FPDFPageObjMark_GetParamKey(
  FPDF_PAGEOBJECTMARK mark,
  int index,
  ffi.Pointer<FPDF_WCHAR> buffer,
  int buflen,
  ffi.Pointer<ffi.UnsignedLong> out_buflen,
) {
  return _FPDFPageObjMark_GetParamKey(
    mark,
    index,
    buffer,
    buflen,
    out_buflen,
  );
}