FPDFPageObjMark_GetParamStringValue method
int
FPDFPageObjMark_GetParamStringValue(
- FPDF_PAGEOBJECTMARK mark,
- FPDF_BYTESTRING key,
- Pointer<
FPDF_WCHAR> buffer, - int buflen,
- Pointer<
UnsignedLong> out_buflen,
Experimental API. Get the value of a string property in a content mark by key.
mark - handle to a content mark. key - string key of the property. buffer - buffer for holding the returned value in UTF-16LE. This is only modified if |buflen| is large enough to store the value. Optional, pass null to just retrieve the size of the buffer needed. buflen - length of the buffer in bytes. out_buflen - pointer to variable that will receive the minimum buffer size in bytes to contain the name. This is a required parameter. Not filled if FALSE is returned.
Returns TRUE if the key maps to a string/blob value, FALSE otherwise.
Implementation
int FPDFPageObjMark_GetParamStringValue(
FPDF_PAGEOBJECTMARK mark,
FPDF_BYTESTRING key,
ffi.Pointer<FPDF_WCHAR> buffer,
int buflen,
ffi.Pointer<ffi.UnsignedLong> out_buflen,
) {
return _FPDFPageObjMark_GetParamStringValue(
mark,
key,
buffer,
buflen,
out_buflen,
);
}