FPDFPageObj_CreateTextObj method
FPDF_PAGEOBJECT
FPDFPageObj_CreateTextObj(
- FPDF_DOCUMENT document,
- FPDF_FONT font,
- double font_size
Create a new text object using a loaded font.
document - handle to the document. font - handle to the font object. font_size - the font size for the new text object.
Returns a handle to a new text object, or NULL on failure
Implementation
FPDF_PAGEOBJECT FPDFPageObj_CreateTextObj(
FPDF_DOCUMENT document,
FPDF_FONT font,
double font_size,
) {
return _FPDFPageObj_CreateTextObj(document, font, font_size);
}