FPDFPageObj_GetBounds method

int FPDFPageObj_GetBounds(
  1. FPDF_PAGEOBJECT page_object,
  2. Pointer<Float> left,
  3. Pointer<Float> bottom,
  4. Pointer<Float> right,
  5. Pointer<Float> top,
)

Get the bounding box of |page_object|.

page_object - handle to a page object. left - pointer where the left coordinate will be stored bottom - pointer where the bottom coordinate will be stored right - pointer where the right coordinate will be stored top - pointer where the top coordinate will be stored

On success, returns TRUE and fills in the 4 coordinates.

Implementation

int FPDFPageObj_GetBounds(
  FPDF_PAGEOBJECT page_object,
  ffi.Pointer<ffi.Float> left,
  ffi.Pointer<ffi.Float> bottom,
  ffi.Pointer<ffi.Float> right,
  ffi.Pointer<ffi.Float> top,
) {
  return _FPDFPageObj_GetBounds(page_object, left, bottom, right, top);
}