FPDFPageObj_GetMark method

FPDF_PAGEOBJECTMARK FPDFPageObj_GetMark(
  1. FPDF_PAGEOBJECT page_object,
  2. int index
)

Experimental API. Get content mark in |page_object| at |index|.

page_object - handle to a page object. index - the index of a page object.

Returns the handle to the content mark, or NULL on failure. The handle is still owned by the library, and it should not be freed directly. It becomes invalid if the page object is destroyed, either directly or indirectly by unloading the page.

Implementation

FPDF_PAGEOBJECTMARK FPDFPageObj_GetMark(
  FPDF_PAGEOBJECT page_object,
  int index,
) {
  return _FPDFPageObj_GetMark(page_object, index);
}