FPDFPageObj_GetMatrix method

int FPDFPageObj_GetMatrix(
  1. FPDF_PAGEOBJECT page_object,
  2. Pointer<FS_MATRIX> matrix
)

Experimental API. Get the transform matrix of a page object.

page_object - handle to a page object. matrix - pointer to struct to receive the matrix value.

The matrix is composed as: |a c e| |b d f| and used to scale, rotate, shear and translate the page object.

For page objects outside form objects, the matrix values are relative to the page that contains it. For page objects inside form objects, the matrix values are relative to the form that contains it.

Returns TRUE on success.

Implementation

int FPDFPageObj_GetMatrix(
  FPDF_PAGEOBJECT page_object,
  ffi.Pointer<FS_MATRIX> matrix,
) {
  return _FPDFPageObj_GetMatrix(page_object, matrix);
}