FPDFPageObj_NewTextObj method

FPDF_PAGEOBJECT FPDFPageObj_NewTextObj(
  1. FPDF_DOCUMENT document,
  2. FPDF_BYTESTRING font,
  3. double font_size
)

Create a new text object using one of the standard PDF fonts.

document - handle to the document. font - string containing the font name, without spaces. font_size - the font size for the new text object.

Returns a handle to a new text object, or NULL on failure

Implementation

FPDF_PAGEOBJECT FPDFPageObj_NewTextObj(
  FPDF_DOCUMENT document,
  FPDF_BYTESTRING font,
  double font_size,
) {
  return _FPDFPageObj_NewTextObj(document, font, font_size);
}