FPDFPageObj_SetIsActive method
Experimental API. Sets if |page_object| is active within page.
page_object - handle to a page object. active - a boolean specifying if the object is active.
Returns TRUE on success.
Page objects all start in the active state by default, and remain in that state unless this function is called.
When |active| is false, this makes the |page_object| be treated as if it wasn't in the document even though it is still held internally.
Implementation
int FPDFPageObj_SetIsActive(FPDF_PAGEOBJECT page_object, int active) {
return _FPDFPageObj_SetIsActive(page_object, active);
}