FPDFPageObj_TransformF method

int FPDFPageObj_TransformF(
  1. FPDF_PAGEOBJECT page_object,
  2. Pointer<FS_MATRIX> matrix
)

Experimental API. Transform |page_object| by the given matrix.

page_object - handle to a page object. matrix - the transform matrix.

Returns TRUE on success.

This can be used to scale, rotate, shear and translate the |page_object|. It is an improved version of FPDFPageObj_Transform() that does not do unnecessary double to float conversions, and only uses 1 parameter for the matrix. It also returns whether the operation succeeded or not.

Implementation

int FPDFPageObj_TransformF(
  FPDF_PAGEOBJECT page_object,
  ffi.Pointer<FS_MATRIX> matrix,
) {
  return _FPDFPageObj_TransformF(page_object, matrix);
}