FPDFPage_GetRawThumbnailData method

int FPDFPage_GetRawThumbnailData(
  1. FPDF_PAGE page,
  2. Pointer<Void> buffer,
  3. int buflen
)

Experimental API. Gets the raw data from the thumbnail of |page| if it exists. This only modifies |buffer| if |buflen| is less than or equal to the size of the raw data. Returns the size of the raw data or 0 if thumbnail DNE. Optional, pass null to just retrieve the size of the buffer needed.

page - handle to a page. buffer - buffer for holding the raw image data. buflen - length of the buffer in bytes.

Implementation

int FPDFPage_GetRawThumbnailData(
  FPDF_PAGE page,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
) {
  return _FPDFPage_GetRawThumbnailData(page, buffer, buflen);
}