FPDFPage_GetTrimBox method

int FPDFPage_GetTrimBox(
  1. FPDF_PAGE page,
  2. Pointer<Float> left,
  3. Pointer<Float> bottom,
  4. Pointer<Float> right,
  5. Pointer<Float> top,
)

Get "TrimBox" entry from the page dictionary.

page - Handle to a page. left - Pointer to a float value receiving the left of the rectangle. bottom - Pointer to a float value receiving the bottom of the rectangle. right - Pointer to a float value receiving the right of the rectangle. top - Pointer to a float value receiving the top of the rectangle.

On success, return true and write to the out parameters. Otherwise return false and leave the out parameters unmodified.

Implementation

int FPDFPage_GetTrimBox(
  FPDF_PAGE page,
  ffi.Pointer<ffi.Float> left,
  ffi.Pointer<ffi.Float> bottom,
  ffi.Pointer<ffi.Float> right,
  ffi.Pointer<ffi.Float> top,
) {
  return _FPDFPage_GetTrimBox(page, left, bottom, right, top);
}