FPDFPage_New method
Create a new PDF page.
document - handle to document. page_index - suggested 0-based index of the page to create. If it is larger than document's current last index(L), the created page index is the next available index -- L+1. width - the page width in points. height - the page height in points.
Returns the handle to the new page or NULL on failure.
The page should be closed with FPDF_ClosePage() when finished as with any other page in the document.
Implementation
FPDF_PAGE FPDFPage_New(
FPDF_DOCUMENT document,
int page_index,
double width,
double height,
) {
return _FPDFPage_New(document, page_index, width, height);
}