FPDFSignatureObj_GetContents method

int FPDFSignatureObj_GetContents(
  1. FPDF_SIGNATURE signature,
  2. Pointer<Void> buffer,
  3. int length
)

Experimental API. Function: FPDFSignatureObj_GetContents Get the contents of a signature object. Parameters: signature - Handle to the signature object. Returned by FPDF_GetSignatureObject(). buffer - The address of a buffer that receives the contents. length - The size, in bytes, of |buffer|. Return value: Returns the number of bytes in the contents on success, 0 on error.

For public-key signatures, |buffer| is either a DER-encoded PKCS#1 binary or a DER-encoded PKCS#7 binary. If |length| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.

Implementation

int FPDFSignatureObj_GetContents(
  FPDF_SIGNATURE signature,
  ffi.Pointer<ffi.Void> buffer,
  int length,
) {
  return _FPDFSignatureObj_GetContents(signature, buffer, length);
}