FPDFText_GetFontWeight method
Experimental API. Function: FPDFText_GetFontWeight Get the font weight of a particular character. Parameters: text_page - Handle to a text page information structure. Returned by FPDFText_LoadPage function. index - Zero-based index of the character. Return value: On success, return the font weight of the particular character. If |text_page| is invalid, if |index| is out of bounds, or if the character's text object is undefined, return -1.
Implementation
int FPDFText_GetFontWeight(FPDF_TEXTPAGE text_page, int index) {
return _FPDFText_GetFontWeight(text_page, index);
}