FPDF_CreateNewDocument method
Create a new PDF document.
Returns a handle to a new document, or NULL on failure.
Implementation
FPDF_DOCUMENT FPDF_CreateNewDocument() {
return _FPDF_CreateNewDocument();
}
Create a new PDF document.
Returns a handle to a new document, or NULL on failure.
FPDF_DOCUMENT FPDF_CreateNewDocument() {
return _FPDF_CreateNewDocument();
}