FPDF_DestroyLibrary method
void
FPDF_DestroyLibrary()
Function: FPDF_DestroyLibrary Release global resources allocated to the PDFium library by FPDF_InitLibrary() or FPDF_InitLibraryWithConfig(). Parameters: None. Return value: None. Comments: After this function is called, you must not call any PDF processing functions.
Calling this function does not automatically close other objects. It is recommended to close other objects before closing the library with this function.
Implementation
void FPDF_DestroyLibrary() {
return _FPDF_DestroyLibrary();
}