FPDF_GetDefaultSystemFontInfo method

Pointer<FPDF_SYSFONTINFO> FPDF_GetDefaultSystemFontInfo()

Function: FPDF_GetDefaultSystemFontInfo Get default system font info interface for current platform Parameters: None Return Value: Pointer to a FPDF_SYSFONTINFO structure describing the default interface, or NULL if the platform doesn't have a default interface. Application should call FPDF_FreeDefaultSystemFontInfo to free the returned pointer. Comments: For some platforms, PDFium implements a default version of system font info interface. The default implementation can be passed to FPDF_SetSystemFontInfo().

Implementation

ffi.Pointer<FPDF_SYSFONTINFO> FPDF_GetDefaultSystemFontInfo() {
  return _FPDF_GetDefaultSystemFontInfo();
}