FPDF_GetDocUserPermissions method
Function: FPDF_GetDocUserPermissions Get user file permission flags of the document. Parameters: document - Handle to a document. Returned by FPDF_LoadDocument. Return value: A 32-bit integer indicating permission flags. Please refer to the PDF Reference for detailed descriptions. If the document is not protected, 0xffffffff will be returned. Always returns user permissions, even if the document was unlocked by the owner.
Implementation
int FPDF_GetDocUserPermissions(FPDF_DOCUMENT document) {
return _FPDF_GetDocUserPermissions(document);
}