FPDF_GetFileIdentifier method
int
FPDF_GetFileIdentifier(
- FPDF_DOCUMENT document,
- FPDF_FILEIDTYPE id_type,
- Pointer<
Void> buffer, - int buflen,
Experimental API. Get the file identifer defined in the trailer of |document|.
document - handle to the document. id_type - the file identifier type to retrieve. buffer - a buffer for the file identifier. May be NULL. buflen - the length of the buffer, in bytes. May be 0.
Returns the number of bytes in the file identifier, including the NUL terminator.
The |buffer| is always a byte string. The |buffer| is followed by a NUL terminator. If |buflen| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
int FPDF_GetFileIdentifier(
FPDF_DOCUMENT document,
FPDF_FILEIDTYPE id_type,
ffi.Pointer<ffi.Void> buffer,
int buflen,
) {
return _FPDF_GetFileIdentifier(document, id_type.value, buffer, buflen);
}