FPDF_GetPageAAction method

FPDF_ACTION FPDF_GetPageAAction(
  1. FPDF_PAGE page,
  2. int aa_type
)

Experimental API Gets an additional-action from |page|.

page - handle to the page, as returned by FPDF_LoadPage(). aa_type - the type of the page object's addtional-action, defined in public/fpdf_formfill.h

Returns the handle to the action data, or NULL if there is no additional-action of type |aa_type|. If this function returns a valid handle, it is valid as long as |page| is valid.

Implementation

FPDF_ACTION FPDF_GetPageAAction(FPDF_PAGE page, int aa_type) {
  return _FPDF_GetPageAAction(page, aa_type);
}