FPDF_GetPageBoundingBox method

int FPDF_GetPageBoundingBox(
  1. FPDF_PAGE page,
  2. Pointer<FS_RECTF> rect
)

Experimental API. Function: FPDF_GetPageBoundingBox Get the bounding box of the page. This is the intersection between its media box and its crop box. Parameters: page - Handle to the page. Returned by FPDF_LoadPage. rect - Pointer to a rect to receive the page bounding box. On an error, |rect| won't be filled. Return value: True for success.

Implementation

int FPDF_GetPageBoundingBox(FPDF_PAGE page, ffi.Pointer<FS_RECTF> rect) {
  return _FPDF_GetPageBoundingBox(page, rect);
}