FPDF_RemoveFormFieldHighlight method

void FPDF_RemoveFormFieldHighlight(
  1. FPDF_FORMHANDLE hHandle
)

Function: FPDF_RemoveFormFieldHighlight Remove the form field highlight color in the document. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). Return Value: None. Comments: Please refresh the client window to remove the highlight immediately if necessary.

Implementation

void FPDF_RemoveFormFieldHighlight(FPDF_FORMHANDLE hHandle) {
  return _FPDF_RemoveFormFieldHighlight(hHandle);
}