FPDF_RenderPage_Continue method
Function: FPDF_RenderPage_Continue Continue rendering a PDF page. Parameters: page - Handle to the page, as returned by FPDF_LoadPage(). pause - The IFSDK_PAUSE interface (a callback mechanism allowing the page rendering process to be paused before it's finished). This can be NULL if you don't want to pause. Return value: The rendering status. See flags for progressive process status for the details.
Implementation
int FPDF_RenderPage_Continue(FPDF_PAGE page, ffi.Pointer<IFSDK_PAUSE> pause) {
return _FPDF_RenderPage_Continue(page, pause);
}