FPDF_SetSystemFontInfo method
Function: FPDF_SetSystemFontInfo Set the system font info interface into PDFium Parameters: font_info - Pointer to a FPDF_SYSFONTINFO structure Return Value: None Comments: Platform support implementation should implement required methods of FFDF_SYSFONTINFO interface, then call this function during PDFium initialization process.
Call this with NULL to tell PDFium to stop using a previously set |FPDF_SYSFONTINFO|.
Implementation
void FPDF_SetSystemFontInfo(ffi.Pointer<FPDF_SYSFONTINFO> font_info) {
return _FPDF_SetSystemFontInfo(font_info);
}