FPDF_StructElement_GetActualText method

int FPDF_StructElement_GetActualText(
  1. FPDF_STRUCTELEMENT struct_element,
  2. Pointer<Void> buffer,
  3. int buflen
)

Experimental API. Function: FPDF_StructElement_GetActualText Get the actual text for a given element. Parameters: struct_element - Handle to the struct element. buffer - A buffer for output the actual text. May be NULL. buflen - The length of the buffer, in bytes. May be 0. Return value: The number of bytes in the actual text, including the terminating NUL character. The number of bytes is returned regardless of the |buffer| and |buflen| parameters. Comments: Regardless of the platform, the |buffer| is always in UTF-16LE encoding. The string is terminated by a UTF16 NUL character. If |buflen| is less than the required length, or |buffer| is NULL, |buffer| will not be modified.

Implementation

int FPDF_StructElement_GetActualText(
  FPDF_STRUCTELEMENT struct_element,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
) {
  return _FPDF_StructElement_GetActualText(struct_element, buffer, buflen);
}