FPDF_StructElement_GetAltText method
int
FPDF_StructElement_GetAltText(
- FPDF_STRUCTELEMENT struct_element,
- Pointer<
Void> buffer, - int buflen
Function: FPDF_StructElement_GetAltText Get the alt text for a given element. Parameters: struct_element - Handle to the struct element. buffer - A buffer for output the alt text. May be NULL. buflen - The length of the buffer, in bytes. May be 0. Return value: The number of bytes in the alt text, including the terminating NUL character. The number of bytes is returned regardless of the |buffer| and |buflen| parameters. Comments: Regardless of the platform, the |buffer| is always in UTF-16LE encoding. The string is terminated by a UTF16 NUL character. If |buflen| is less than the required length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
int FPDF_StructElement_GetAltText(
FPDF_STRUCTELEMENT struct_element,
ffi.Pointer<ffi.Void> buffer,
int buflen,
) {
return _FPDF_StructElement_GetAltText(struct_element, buffer, buflen);
}