FPDF_StructElement_GetAttributeAtIndex method
FPDF_STRUCTELEMENT_ATTR
FPDF_StructElement_GetAttributeAtIndex(
- FPDF_STRUCTELEMENT struct_element,
- int index
Experimental API. Function: FPDF_StructElement_GetAttributeAtIndex Get an attribute object in the structure element. Parameters: struct_element - Handle to the struct element. index - The index for the attribute object, 0-based. Return value: The attribute object at the n-th index or NULL on error. Comments: If the attribute object exists but is not a dict, then this function will return NULL. This will also return NULL for out of bounds indices. The caller does not own the handle. The handle remains valid as long as |struct_element| remains valid. The |index| must be less than the FPDF_StructElement_GetAttributeCount() return value.
Implementation
FPDF_STRUCTELEMENT_ATTR FPDF_StructElement_GetAttributeAtIndex(
FPDF_STRUCTELEMENT struct_element,
int index,
) {
return _FPDF_StructElement_GetAttributeAtIndex(struct_element, index);
}