FPDF_StructTree_CountChildren method

int FPDF_StructTree_CountChildren(
  1. FPDF_STRUCTTREE struct_tree
)

Function: FPDF_StructTree_CountChildren Count the number of children for the structure tree. Parameters: struct_tree - Handle to the structure tree, as returned by FPDF_StructTree_LoadPage(). Return value: The number of children, or -1 on error.

Implementation

int FPDF_StructTree_CountChildren(FPDF_STRUCTTREE struct_tree) {
  return _FPDF_StructTree_CountChildren(struct_tree);
}