FORM_IsIndexSelected function
- @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE, Int)>(FPDF_FORMHANDLE, FPDF_PAGE, ffi.Int)>()
- FPDF_FORMHANDLE hHandle,
- FPDF_PAGE page,
- int index
Experimental API Function: FORM_IsIndexSelected Returns whether or not the value at |index| of the focused annotation is currently selected. Parameters: hHandle - Handle to the form fill module. Returned by FPDFDOC_InitFormFillEnvironment. page - Handle to the page. Returned by FPDF_LoadPage index - 0-based Index of value to check Return Value: TRUE if value at |index| is currently selected. FALSE if value at |index| is not selected or widget is not a supported type. Comments: Intended for use with listbox/combobox widget types. Default implementation is a no-op that will return false for other types. Not currently supported for XFA forms - will return false.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE, ffi.Int)>()
external int FORM_IsIndexSelected(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int index,
);