FORM_OnChar function
Function: FORM_OnChar Call this member function when a keystroke translates to a nonsystem character. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). nChar - The character code value itself. modifier - Mask of key flags (see fpdf_fwlevent.h for key flag values). Return Value: True indicates success; otherwise false.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_PAGE, ffi.Int, ffi.Int)>()
external int FORM_OnChar(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int nChar,
int modifier,
);