FORM_OnMouseWheel function
Experimental API Function: FORM_OnMouseWheel Call this member function when the user scrolls the mouse wheel. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). modifier - Indicates whether various virtual keys are down. page_coord - Specifies the coordinates of the cursor in PDF user space. delta_x - Specifies the amount of wheel movement on the x-axis, in units of platform-agnostic wheel deltas. Negative values mean left. delta_y - Specifies the amount of wheel movement on the y-axis, in units of platform-agnostic wheel deltas. Negative values mean down. Return Value: True indicates success; otherwise false. Comments: For |delta_x| and |delta_y|, the caller must normalize platform-specific wheel deltas. e.g. On Windows, a delta value of 240 for a WM_MOUSEWHEEL event normalizes to 2, since Windows defines WHEEL_DELTA as 120.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_FORMHANDLE,
FPDF_PAGE,
ffi.Int,
ffi.Pointer<FS_POINTF>,
ffi.Int,
ffi.Int,
)
>()
external int FORM_OnMouseWheel(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int modifier,
ffi.Pointer<FS_POINTF> page_coord,
int delta_x,
int delta_y,
);