FPDFAction_GetDest function
- @Native<FPDF_DEST Function(FPDF_DOCUMENT document, FPDF_ACTION action)>(FPDF_DOCUMENT, FPDF_ACTION)>()
- FPDF_DOCUMENT document,
- FPDF_ACTION action
Get the destination of |action|.
document - handle to the document. action - handle to the action. |action| must be a |PDFACTION_GOTO| or |PDFACTION_REMOTEGOTO|.
Returns a handle to the destination data, or NULL on error, typically because the arguments were bad or the action was of the wrong type.
In the case of |PDFACTION_REMOTEGOTO|, you must first call FPDFAction_GetFilePath(), then load the document at that path, then pass the document handle from that document as |document| to FPDFAction_GetDest().
Implementation
@ffi.Native<FPDF_DEST Function(FPDF_DOCUMENT, FPDF_ACTION)>()
external FPDF_DEST FPDFAction_GetDest(
FPDF_DOCUMENT document,
FPDF_ACTION action,
);