FPDFAction_GetFilePath function
- @Native<UnsignedLong Function(FPDF_ACTION, Pointer<
Void> , UnsignedLong)>(FPDF_ACTION, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)>()
- FPDF_ACTION action,
- Pointer<
Void> buffer, - int buflen
Get the file path of |action|.
action - handle to the action. |action| must be a |PDFACTION_LAUNCH| or |PDFACTION_REMOTEGOTO|. buffer - a buffer for output the path string. May be NULL. buflen - the length of the buffer, in bytes. May be 0.
Returns the number of bytes in the file path, including the trailing NUL character, or 0 on error, typically because the arguments were bad or the action was of the wrong type.
Regardless of the platform, the |buffer| is always in UTF-8 encoding. If |buflen| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_ACTION,
ffi.Pointer<ffi.Void>,
ffi.UnsignedLong,
)
>()
external int FPDFAction_GetFilePath(
FPDF_ACTION action,
ffi.Pointer<ffi.Void> buffer,
int buflen,
);