FPDFAnnot_CountAttachmentPoints function
- @Native<Size Function(FPDF_ANNOTATION)>(FPDF_ANNOTATION)>()
- FPDF_ANNOTATION annot
Experimental API. Get the number of sets of quadpoints of an annotation.
annot - handle to an annotation.
Returns the number of sets of quadpoints, or 0 on failure.
Implementation
@ffi.Native<ffi.Size Function(FPDF_ANNOTATION)>()
external int FPDFAnnot_CountAttachmentPoints(FPDF_ANNOTATION annot);