FPDFAnnot_GetFormFieldAlternateName function
- @Native<UnsignedLong Function(FPDF_FORMHANDLE, FPDF_ANNOTATION, Pointer<
FPDF_WCHAR> , UnsignedLong)>(FPDF_FORMHANDLE, FPDF_ANNOTATION, ffi.Pointer<FPDF_WCHAR>, ffi.UnsignedLong)>()
- FPDF_FORMHANDLE hHandle,
- FPDF_ANNOTATION annot,
- Pointer<
FPDF_WCHAR> buffer, - int buflen,
Experimental API. Gets the alternate name of |annot|, which is an interactive form annotation. |buffer| is only modified if |buflen| is longer than the length of contents. In case of error, nothing will be added to |buffer| and the return value will be 0. Note that return value of empty string is 2 for "\0\0".
hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment(). annot - handle to an interactive form annotation. buffer - buffer for holding the alternate name string, encoded in UTF-16LE. buflen - length of the buffer in bytes.
Returns the length of the string value in bytes.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_FORMHANDLE,
FPDF_ANNOTATION,
ffi.Pointer<FPDF_WCHAR>,
ffi.UnsignedLong,
)
>()
external int FPDFAnnot_GetFormFieldAlternateName(
FPDF_FORMHANDLE hHandle,
FPDF_ANNOTATION annot,
ffi.Pointer<FPDF_WCHAR> buffer,
int buflen,
);