FPDFAnnot_GetInkListCount function
- @Native<UnsignedLong Function(FPDF_ANNOTATION)>(FPDF_ANNOTATION)>()
- FPDF_ANNOTATION annot
Experimental API. Get the number of paths in the ink list of an ink annotation.
annot - handle to an annotation, as returned by e.g. FPDFPage_GetAnnot()
Returns the number of paths in the ink list if the annotation is of type ink, 0 otherwise.
Implementation
@ffi.Native<ffi.UnsignedLong Function(FPDF_ANNOTATION)>()
external int FPDFAnnot_GetInkListCount(FPDF_ANNOTATION annot);