FPDFAnnot_GetLinkedAnnot function
- @Native<FPDF_ANNOTATION Function(FPDF_ANNOTATION annot, FPDF_BYTESTRING key)>(FPDF_ANNOTATION, FPDF_BYTESTRING)>()
- FPDF_ANNOTATION annot,
- FPDF_BYTESTRING key
Experimental API. Get the annotation corresponding to |key| in |annot|'s dictionary. Common keys for linking annotations include "IRT" and "Popup". Must call FPDFPage_CloseAnnot() when the annotation returned by this function is no longer needed.
annot - handle to an annotation. key - the key to the requested dictionary entry, encoded in UTF-8.
Returns a handle to the linked annotation object, or NULL on failure.
Implementation
@ffi.Native<FPDF_ANNOTATION Function(FPDF_ANNOTATION, FPDF_BYTESTRING)>()
external FPDF_ANNOTATION FPDFAnnot_GetLinkedAnnot(
FPDF_ANNOTATION annot,
FPDF_BYTESTRING key,
);