FPDFAnnot_GetOptionCount function
- @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_ANNOTATION)>(FPDF_FORMHANDLE, FPDF_ANNOTATION)>()
- FPDF_FORMHANDLE hHandle,
- FPDF_ANNOTATION annot
Experimental API. Get the number of options in the |annot|'s "Opt" dictionary. Intended for use with listbox and combobox widget annotations.
hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation.
Returns the number of options in "Opt" dictionary on success. Return value will be -1 if annotation does not have an "Opt" dictionary or other error.
Implementation
@ffi.Native<ffi.Int Function(FPDF_FORMHANDLE, FPDF_ANNOTATION)>()
external int FPDFAnnot_GetOptionCount(
FPDF_FORMHANDLE hHandle,
FPDF_ANNOTATION annot,
);