FPDFAnnot_IsOptionSelected function
- @Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_ANNOTATION, Int)>(FPDF_FORMHANDLE, FPDF_ANNOTATION, ffi.Int)>()
- FPDF_FORMHANDLE handle,
- FPDF_ANNOTATION annot,
- int index
Experimental API. Determine whether or not the option at |index| in |annot|'s "Opt" dictionary is selected. Intended for use with listbox and combobox widget annotations.
handle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation. index - numeric index of the option in the "Opt" array.
Returns true if the option at |index| in |annot|'s "Opt" dictionary is selected, false otherwise.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_FORMHANDLE, FPDF_ANNOTATION, ffi.Int)>()
external int FPDFAnnot_IsOptionSelected(
FPDF_FORMHANDLE handle,
FPDF_ANNOTATION annot,
int index,
);