FPDFAnnot_SetAttachmentPoints function
- @Native<FPDF_BOOL Function(FPDF_ANNOTATION, Size, Pointer<
FS_QUADPOINTSF> )>(FPDF_ANNOTATION, ffi.Size, ffi.Pointer<FS_QUADPOINTSF>)>()
- FPDF_ANNOTATION annot,
- int quad_index,
- Pointer<
FS_QUADPOINTSF> quad_points
Experimental API. Replace the attachment points (i.e. quadpoints) set of an annotation at |quad_index|. This index needs to be within the result of FPDFAnnot_CountAttachmentPoints(). If the annotation's appearance stream is defined and this annotation is of a type with quadpoints, then update the bounding box too if the new quadpoints define a bigger one.
annot - handle to an annotation. quad_index - index of the set of quadpoints. quad_points - the quadpoints to be set.
Returns true if successful.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_ANNOTATION, ffi.Size, ffi.Pointer<FS_QUADPOINTSF>)
>()
external int FPDFAnnot_SetAttachmentPoints(
FPDF_ANNOTATION annot,
int quad_index,
ffi.Pointer<FS_QUADPOINTSF> quad_points,
);