FPDFAnnot_SetStringValue function
- @Native<FPDF_BOOL Function(FPDF_ANNOTATION, FPDF_BYTESTRING, FPDF_WIDESTRING)>(FPDF_ANNOTATION, FPDF_BYTESTRING, FPDF_WIDESTRING)>()
- FPDF_ANNOTATION annot,
- FPDF_BYTESTRING key,
- FPDF_WIDESTRING value
Experimental API. Set the string value corresponding to |key| in |annot|'s dictionary, overwriting the existing value if any. The value type would be FPDF_OBJECT_STRING after this function call succeeds.
annot - handle to an annotation. key - the key to the dictionary entry to be set, encoded in UTF-8. value - the string value to be set, encoded in UTF-16LE.
Returns true if successful.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_ANNOTATION, FPDF_BYTESTRING, FPDF_WIDESTRING)
>()
external int FPDFAnnot_SetStringValue(
FPDF_ANNOTATION annot,
FPDF_BYTESTRING key,
FPDF_WIDESTRING value,
);