FPDFAttachment_GetName function
- @Native<UnsignedLong Function(FPDF_ATTACHMENT, Pointer<
FPDF_WCHAR> , UnsignedLong)>(FPDF_ATTACHMENT, ffi.Pointer<FPDF_WCHAR>, ffi.UnsignedLong)>()
- FPDF_ATTACHMENT attachment,
- Pointer<
FPDF_WCHAR> buffer, - int buflen
Experimental API. Get the name of the |attachment| file. |buffer| is only modified if |buflen| is longer than the length of the file name. On errors, |buffer| is unmodified and the returned length is 0.
attachment - handle to an attachment. buffer - buffer for holding the file name, encoded in UTF-16LE. buflen - length of the buffer in bytes.
Returns the length of the file name in bytes.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_ATTACHMENT,
ffi.Pointer<FPDF_WCHAR>,
ffi.UnsignedLong,
)
>()
external int FPDFAttachment_GetName(
FPDF_ATTACHMENT attachment,
ffi.Pointer<FPDF_WCHAR> buffer,
int buflen,
);