FPDFAttachment_SetStringValue function
- @Native<FPDF_BOOL Function(FPDF_ATTACHMENT, FPDF_BYTESTRING, FPDF_WIDESTRING)>(FPDF_ATTACHMENT, FPDF_BYTESTRING, FPDF_WIDESTRING)>()
- FPDF_ATTACHMENT attachment,
- FPDF_BYTESTRING key,
- FPDF_WIDESTRING value
Experimental API. Set the string value corresponding to |key| in the params dictionary of the embedded file |attachment|, overwriting the existing value if any. The value type should be FPDF_OBJECT_STRING after this function call succeeds.
attachment - handle to an attachment. key - the key to the dictionary entry, encoded in UTF-8. value - the string value to be set, encoded in UTF-16LE.
Returns true if successful.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_ATTACHMENT, FPDF_BYTESTRING, FPDF_WIDESTRING)
>()
external int FPDFAttachment_SetStringValue(
FPDF_ATTACHMENT attachment,
FPDF_BYTESTRING key,
FPDF_WIDESTRING value,
);