FPDFAvail_IsPageAvail function
- @Native<Int Function(FPDF_AVAIL, Int, Pointer<
FX_DOWNLOADHINTS> )>(FPDF_AVAIL, ffi.Int, ffi.Pointer<FX_DOWNLOADHINTS>)>()
- FPDF_AVAIL avail,
- int page_index,
- Pointer<
FX_DOWNLOADHINTS> hints
Check if |page_index| is ready for loading, if not, get the |FX_DOWNLOADHINTS|.
avail - handle to document availability provider. page_index - index number of the page. Zero for the first page. hints - pointer to a download hints interface. Populated if |page_index| is not available.
Returns one of: PDF_DATA_ERROR: A common error is returned. Data availability unknown. PDF_DATA_NOTAVAIL: Data not yet available. PDF_DATA_AVAIL: Data available.
This function can be called only after FPDFAvail_GetDocument() is called. Applications should call this function whenever new data arrives and process all the generated download |hints|, if any, until this function returns |PDF_DATA_ERROR| or |PDF_DATA_AVAIL|. Applications can then perform page loading. if hints is nullptr, the function just check current availability of specified page.
Implementation
@ffi.Native<
ffi.Int Function(FPDF_AVAIL, ffi.Int, ffi.Pointer<FX_DOWNLOADHINTS>)
>()
external int FPDFAvail_IsPageAvail(
FPDF_AVAIL avail,
int page_index,
ffi.Pointer<FX_DOWNLOADHINTS> hints,
);