FPDFBitmap_GetBuffer function
- @Native<Pointer<
Void> Function(FPDF_BITMAP bitmap)>(FPDF_BITMAP)>()
- FPDF_BITMAP bitmap
Function: FPDFBitmap_GetBuffer Get data buffer of a bitmap. Parameters: bitmap - Handle to the bitmap. Returned by FPDFBitmap_Create or FPDFImageObj_GetBitmap. Return value: The pointer to the first byte of the bitmap buffer. Comments: The stride may be more than width * number of bytes per pixel
Applications can use this function to get the bitmap buffer pointer, then manipulate any color and/or alpha values for any pixels in the bitmap.
Use FPDFBitmap_GetFormat() to find out the format of the data.
Implementation
@ffi.Native<ffi.Pointer<ffi.Void> Function(FPDF_BITMAP)>()
external ffi.Pointer<ffi.Void> FPDFBitmap_GetBuffer(FPDF_BITMAP bitmap);