FPDFDoc_GetAttachment function
- @Native<FPDF_ATTACHMENT Function(FPDF_DOCUMENT, Int)>(FPDF_DOCUMENT, ffi.Int)>()
- FPDF_DOCUMENT document,
- int index
Experimental API. Get the embedded attachment at |index| in |document|. Note that the returned attachment handle is only valid while |document| is open.
document - handle to a document. index - the index of the requested embedded file.
Returns the handle to the attachment object, or NULL on failure.
Implementation
@ffi.Native<FPDF_ATTACHMENT Function(FPDF_DOCUMENT, ffi.Int)>()
external FPDF_ATTACHMENT FPDFDoc_GetAttachment(
FPDF_DOCUMENT document,
int index,
);