FPDFFont_GetDescent function
Experimental API. Get descent distance of a font.
font - the handle to the font object. font_size - the size of the |font|. descent - pointer where the font descent will be stored
Descent is the maximum distance in points below the baseline reached by the glyphs of the |font|. One point is 1/72 inch (around 0.3528 mm).
Returns TRUE on success; |descent| unmodified on failure.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_FONT, ffi.Float, ffi.Pointer<ffi.Float>)>()
external int FPDFFont_GetDescent(
FPDF_FONT font,
double font_size,
ffi.Pointer<ffi.Float> descent,
);