FPDFFont_GetFamilyName function
Experimental API. Get the family name of a font.
font - the handle to the font object. buffer - the address of a buffer that receives the font name. length - the size, in bytes, of |buffer|.
Returns the number of bytes in the family name (including the trailing NUL character) on success, 0 on error.
Regardless of the platform, the |buffer| is always in UTF-8 encoding. If |length| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
@ffi.Native<ffi.Size Function(FPDF_FONT, ffi.Pointer<ffi.Char>, ffi.Size)>()
external int FPDFFont_GetFamilyName(
FPDF_FONT font,
ffi.Pointer<ffi.Char> buffer,
int length,
);