FPDFImageObj_GetBitmap function
- @Native<FPDF_BITMAP Function(FPDF_PAGEOBJECT image_object)>(FPDF_PAGEOBJECT)>()
- FPDF_PAGEOBJECT image_object
Get a bitmap rasterization of |image_object|. FPDFImageObj_GetBitmap() only operates on |image_object| and does not take the associated image mask into account. It also ignores the matrix for |image_object|. The returned bitmap will be owned by the caller, and FPDFBitmap_Destroy() must be called on the returned bitmap when it is no longer needed.
image_object - handle to an image object.
Returns the bitmap.
Implementation
@ffi.Native<FPDF_BITMAP Function(FPDF_PAGEOBJECT)>()
external FPDF_BITMAP FPDFImageObj_GetBitmap(FPDF_PAGEOBJECT image_object);