FPDFImageObj_GetRenderedBitmap function
- @Native<FPDF_BITMAP Function(FPDF_DOCUMENT document, FPDF_PAGE page, FPDF_PAGEOBJECT image_object)>(FPDF_DOCUMENT, FPDF_PAGE, FPDF_PAGEOBJECT)>()
- FPDF_DOCUMENT document,
- FPDF_PAGE page,
- FPDF_PAGEOBJECT image_object
Experimental API. Get a bitmap rasterization of |image_object| that takes the image mask and image matrix into account. To render correctly, the caller must provide the |document| associated with |image_object|. If there is a |page| associated with |image_object|, the caller should provide that as well. The returned bitmap will be owned by the caller, and FPDFBitmap_Destroy() must be called on the returned bitmap when it is no longer needed.
document - handle to a document associated with |image_object|. page - handle to an optional page associated with |image_object|. image_object - handle to an image object.
Returns the bitmap or NULL on failure.
Implementation
@ffi.Native<FPDF_BITMAP Function(FPDF_DOCUMENT, FPDF_PAGE, FPDF_PAGEOBJECT)>()
external FPDF_BITMAP FPDFImageObj_GetRenderedBitmap(
FPDF_DOCUMENT document,
FPDF_PAGE page,
FPDF_PAGEOBJECT image_object,
);