FPDFLink_CountRects function
- @Native<Int Function(FPDF_PAGELINK, Int)>(FPDF_PAGELINK, ffi.Int)>()
- FPDF_PAGELINK link_page,
- int link_index
Function: FPDFLink_CountRects Count number of rectangular areas for the link. Parameters: link_page - Handle returned by FPDFLink_LoadWebLinks. link_index - Zero-based index for the link. Return Value: Number of rectangular areas for the link. If |link_index| does not correspond to a valid link, then 0 is returned.
Implementation
@ffi.Native<ffi.Int Function(FPDF_PAGELINK, ffi.Int)>()
external int FPDFLink_CountRects(FPDF_PAGELINK link_page, int link_index);