FPDFPageObjMark_GetParamBlobValue function
- @Native<FPDF_BOOL Function(FPDF_PAGEOBJECTMARK, FPDF_BYTESTRING, Pointer<
UnsignedChar> , UnsignedLong, Pointer<UnsignedLong> )>(FPDF_PAGEOBJECTMARK, FPDF_BYTESTRING, ffi.Pointer<ffi.UnsignedChar>, ffi.UnsignedLong, ffi.Pointer<ffi.UnsignedLong>)>()
- FPDF_PAGEOBJECTMARK mark,
- FPDF_BYTESTRING key,
- Pointer<
UnsignedChar> buffer, - int buflen,
- Pointer<
UnsignedLong> out_buflen,
Experimental API. Get the value of a blob property in a content mark by key.
mark - handle to a content mark. key - string key of the property. buffer - buffer for holding the returned value. This is only modified if |buflen| is large enough to store the value. Optional, pass null to just retrieve the size of the buffer needed. buflen - length of the buffer in bytes. out_buflen - pointer to variable that will receive the minimum buffer size in bytes to contain the name. This is a required parameter. Not filled if FALSE is returned.
Returns TRUE if the key maps to a string/blob value, FALSE otherwise.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_PAGEOBJECTMARK,
FPDF_BYTESTRING,
ffi.Pointer<ffi.UnsignedChar>,
ffi.UnsignedLong,
ffi.Pointer<ffi.UnsignedLong>,
)
>()
external int FPDFPageObjMark_GetParamBlobValue(
FPDF_PAGEOBJECTMARK mark,
FPDF_BYTESTRING key,
ffi.Pointer<ffi.UnsignedChar> buffer,
int buflen,
ffi.Pointer<ffi.UnsignedLong> out_buflen,
);