FPDFPageObj_GetIsActive function
- @Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, Pointer<
Int> )>(FPDF_PAGEOBJECT, ffi.Pointer<FPDF_BOOL>)>()
- FPDF_PAGEOBJECT page_object,
- Pointer<
Int> active
Experimental API. Gets active state for |page_object| within page.
page_object - handle to a page object. active - pointer to variable that will receive if the page object is active. This is a required parameter. Not filled if FALSE is returned.
For page objects where |active| is filled with FALSE, the |page_object| is treated as if it wasn't in the document even though it is still held internally.
Returns TRUE if the operation succeeded, FALSE if it failed.
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_PAGEOBJECT, ffi.Pointer<FPDF_BOOL>)>()
external int FPDFPageObj_GetIsActive(
FPDF_PAGEOBJECT page_object,
ffi.Pointer<FPDF_BOOL> active,
);