FPDFPageObj_NewTextObj function
- @Native<FPDF_PAGEOBJECT Function(FPDF_DOCUMENT, FPDF_BYTESTRING, Float)>(FPDF_DOCUMENT, FPDF_BYTESTRING, ffi.Float)>()
- FPDF_DOCUMENT document,
- FPDF_BYTESTRING font,
- double font_size
Create a new text object using one of the standard PDF fonts.
document - handle to the document. font - string containing the font name, without spaces. font_size - the font size for the new text object.
Returns a handle to a new text object, or NULL on failure
Implementation
@ffi.Native<
FPDF_PAGEOBJECT Function(FPDF_DOCUMENT, FPDF_BYTESTRING, ffi.Float)
>()
external FPDF_PAGEOBJECT FPDFPageObj_NewTextObj(
FPDF_DOCUMENT document,
FPDF_BYTESTRING font,
double font_size,
);