FPDFPage_GetAnnot function
- @Native<FPDF_ANNOTATION Function(FPDF_PAGE, FPDF_ANNOTATION_SUBTYPE)>(FPDF_PAGE, ffi.Int)>()
Experimental API. Get annotation in |page| at |index|. Must call FPDFPage_CloseAnnot() when the annotation returned by this function is no longer needed.
page - handle to a page. index - the index of the annotation.
Returns a handle to the annotation object, or NULL on failure.
Implementation
@ffi.Native<FPDF_ANNOTATION Function(FPDF_PAGE, ffi.Int)>()
external FPDF_ANNOTATION FPDFPage_GetAnnot(FPDF_PAGE page, int index);