FPDFPage_GetDecodedThumbnailData function
- @Native<UnsignedLong Function(FPDF_PAGE, Pointer<
Void> , UnsignedLong)>(FPDF_PAGE, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)>()
Experimental API. Gets the decoded data from the thumbnail of |page| if it exists. This only modifies |buffer| if |buflen| less than or equal to the size of the decoded data. Returns the size of the decoded data or 0 if thumbnail DNE. Optional, pass null to just retrieve the size of the buffer needed.
page - handle to a page. buffer - buffer for holding the decoded image data. buflen - length of the buffer in bytes.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(FPDF_PAGE, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)
>()
external int FPDFPage_GetDecodedThumbnailData(
FPDF_PAGE page,
ffi.Pointer<ffi.Void> buffer,
int buflen,
);