FPDFPage_TransFormWithClip function
Apply transforms to |page|.
If |matrix| is provided it will be applied to transform the page. If |clipRect| is provided it will be used to clip the resulting page. If neither |matrix| or |clipRect| are provided this method returns |false|. Returns |true| if transforms are applied.
This function will transform the whole page, and would take effect to all the objects in the page.
page - Page handle. matrix - Transform matrix. clipRect - Clipping rectangle.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_PAGE, ffi.Pointer<FS_MATRIX>, ffi.Pointer<FS_RECTF>)
>()
external int FPDFPage_TransFormWithClip(
FPDF_PAGE page,
ffi.Pointer<FS_MATRIX> matrix,
ffi.Pointer<FS_RECTF> clipRect,
);