FPDFPath_BezierTo function
Add a cubic Bezier curve to the given path, starting at the current point.
path - the handle to the path object. x1 - the horizontal position of the first Bezier control point. y1 - the vertical position of the first Bezier control point. x2 - the horizontal position of the second Bezier control point. y2 - the vertical position of the second Bezier control point. x3 - the horizontal position of the ending point of the Bezier curve. y3 - the vertical position of the ending point of the Bezier curve.
Returns TRUE on success
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_PAGEOBJECT,
ffi.Float,
ffi.Float,
ffi.Float,
ffi.Float,
ffi.Float,
ffi.Float,
)
>()
external int FPDFPath_BezierTo(
FPDF_PAGEOBJECT path,
double x1,
double y1,
double x2,
double y2,
double x3,
double y3,
);