FPDFPath_Close function
- @Native<FPDF_BOOL Function(FPDF_PAGEOBJECT)>(FPDF_PAGEOBJECT)>()
- FPDF_PAGEOBJECT path
Close the current subpath of a given path.
path - the handle to the path object.
This will add a line between the current point and the initial point of the subpath, thus terminating the current subpath.
Returns TRUE on success
Implementation
@ffi.Native<FPDF_BOOL Function(FPDF_PAGEOBJECT)>()
external int FPDFPath_Close(FPDF_PAGEOBJECT path);