FPDFSignatureObj_GetByteRange function
- @Native<UnsignedLong Function(FPDF_SIGNATURE, Pointer<
Int> , UnsignedLong)>(FPDF_SIGNATURE, ffi.Pointer<ffi.Int>, ffi.UnsignedLong)>()
- FPDF_SIGNATURE signature,
- Pointer<
Int> buffer, - int length
Experimental API. Function: FPDFSignatureObj_GetByteRange Get the byte range of a signature object. Parameters: signature - Handle to the signature object. Returned by FPDF_GetSignatureObject(). buffer - The address of a buffer that receives the byte range. length - The size, in ints, of |buffer|. Return value: Returns the number of ints in the byte range on success, 0 on error.
|buffer| is an array of pairs of integers (starting byte offset, length in bytes) that describes the exact byte range for the digest calculation. If |length| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_SIGNATURE,
ffi.Pointer<ffi.Int>,
ffi.UnsignedLong,
)
>()
external int FPDFSignatureObj_GetByteRange(
FPDF_SIGNATURE signature,
ffi.Pointer<ffi.Int> buffer,
int length,
);