FPDFSignatureObj_GetReason function
- @Native<UnsignedLong Function(FPDF_SIGNATURE, Pointer<
Void> , UnsignedLong)>(FPDF_SIGNATURE, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)>()
- FPDF_SIGNATURE signature,
- Pointer<
Void> buffer, - int length
Experimental API. Function: FPDFSignatureObj_GetReason Get the reason (comment) of the signature object. Parameters: signature - Handle to the signature object. Returned by FPDF_GetSignatureObject(). buffer - The address of a buffer that receives the reason. length - The size, in bytes, of |buffer|. Return value: Returns the number of bytes in the reason on success, 0 on error.
Regardless of the platform, the |buffer| is always in UTF-16LE encoding. The string is terminated by a UTF16 NUL character. If |length| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_SIGNATURE,
ffi.Pointer<ffi.Void>,
ffi.UnsignedLong,
)
>()
external int FPDFSignatureObj_GetReason(
FPDF_SIGNATURE signature,
ffi.Pointer<ffi.Void> buffer,
int length,
);