FPDFTextObj_GetRenderedBitmap function
- @Native<FPDF_BITMAP Function(FPDF_DOCUMENT, FPDF_PAGE, FPDF_PAGEOBJECT, Float)>(FPDF_DOCUMENT, FPDF_PAGE, FPDF_PAGEOBJECT, ffi.Float)>()
- FPDF_DOCUMENT document,
- FPDF_PAGE page,
- FPDF_PAGEOBJECT text_object,
- double scale,
Experimental API. Get a bitmap rasterization of |text_object|. To render correctly, the caller must provide the |document| associated with |text_object|. If there is a |page| associated with |text_object|, the caller should provide that as well. The returned bitmap will be owned by the caller, and FPDFBitmap_Destroy() must be called on the returned bitmap when it is no longer needed.
document - handle to a document associated with |text_object|. page - handle to an optional page associated with |text_object|. text_object - handle to a text object. scale - the scaling factor, which must be greater than 0.
Returns the bitmap or NULL on failure.
Implementation
@ffi.Native<
FPDF_BITMAP Function(FPDF_DOCUMENT, FPDF_PAGE, FPDF_PAGEOBJECT, ffi.Float)
>()
external FPDF_BITMAP FPDFTextObj_GetRenderedBitmap(
FPDF_DOCUMENT document,
FPDF_PAGE page,
FPDF_PAGEOBJECT text_object,
double scale,
);