FPDFTextObj_GetText function
- @Native<UnsignedLong Function(FPDF_PAGEOBJECT, FPDF_TEXTPAGE, Pointer<
FPDF_WCHAR> , UnsignedLong)>(FPDF_PAGEOBJECT, FPDF_TEXTPAGE, ffi.Pointer<FPDF_WCHAR>, ffi.UnsignedLong)>()
- FPDF_PAGEOBJECT text_object,
- FPDF_TEXTPAGE text_page,
- Pointer<
FPDF_WCHAR> buffer, - int length,
Get the text of a text object.
text_object - the handle to the text object. text_page - the handle to the text page. buffer - the address of a buffer that receives the text. length - the size, in bytes, of |buffer|.
Returns the number of bytes in the text (including the trailing NUL character) on success, 0 on error.
Regardless of the platform, the |buffer| is always in UTF-16LE encoding. If |length| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_PAGEOBJECT,
FPDF_TEXTPAGE,
ffi.Pointer<FPDF_WCHAR>,
ffi.UnsignedLong,
)
>()
external int FPDFTextObj_GetText(
FPDF_PAGEOBJECT text_object,
FPDF_TEXTPAGE text_page,
ffi.Pointer<FPDF_WCHAR> buffer,
int length,
);