FPDFText_GetCharOrigin function
Function: FPDFText_GetCharOrigin Get origin of a particular character. Parameters: text_page - Handle to a text page information structure. Returned by FPDFText_LoadPage function. index - Zero-based index of the character. x - Pointer to a double number receiving x coordinate of the character origin. y - Pointer to a double number receiving y coordinate of the character origin. Return Value: Whether the call succeeded. If false, x and y are unchanged. Comments: All positions are measured in PDF "user space".
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_TEXTPAGE,
ffi.Int,
ffi.Pointer<ffi.Double>,
ffi.Pointer<ffi.Double>,
)
>()
external int FPDFText_GetCharOrigin(
FPDF_TEXTPAGE text_page,
int index,
ffi.Pointer<ffi.Double> x,
ffi.Pointer<ffi.Double> y,
);