FPDFText_GetFontSize function
- @Native<Double Function(FPDF_TEXTPAGE, Int)>(FPDF_TEXTPAGE, ffi.Int)>()
- FPDF_TEXTPAGE text_page,
- int index
Function: FPDFText_GetFontSize Get the font size of a particular character. Parameters: text_page - Handle to a text page information structure. Returned by FPDFText_LoadPage function. index - Zero-based index of the character. Return value: The font size of the particular character, measured in points (about 1/72 inch). This is the typographic size of the font (so called "em size").
Implementation
@ffi.Native<ffi.Double Function(FPDF_TEXTPAGE, ffi.Int)>()
external double FPDFText_GetFontSize(FPDF_TEXTPAGE text_page, int index);