FPDFText_GetUnicode function
- @Native<UnsignedInt Function(FPDF_TEXTPAGE, Int)>(FPDF_TEXTPAGE, ffi.Int)>()
- FPDF_TEXTPAGE text_page,
- int index
Function: FPDFText_GetUnicode Get Unicode of a character in a page. Parameters: text_page - Handle to a text page information structure. Returned by FPDFText_LoadPage function. index - Zero-based index of the character. Return value: The Unicode of the particular character. If a character is not encoded in Unicode and Foxit engine can't convert to Unicode, the return value will be zero.
Implementation
@ffi.Native<ffi.UnsignedInt Function(FPDF_TEXTPAGE, ffi.Int)>()
external int FPDFText_GetUnicode(FPDF_TEXTPAGE text_page, int index);