FPDFText_SetCharcodes function
Experimental API. Set the text using charcodes for a text object. If it had text, it will be replaced.
text_object - handle to the text object. charcodes - pointer to an array of charcodes to be added. count - number of elements in |charcodes|.
Returns TRUE on success. Fails if |text_object| or |charcodes| is null, or |count| is 0.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_PAGEOBJECT, ffi.Pointer<ffi.Uint32>, ffi.Size)
>()
external int FPDFText_SetCharcodes(
FPDF_PAGEOBJECT text_object,
ffi.Pointer<ffi.Uint32> charcodes,
int count,
);