WriteBlock property
Pointer<NativeFunction<FPDF_RESULT Function(Pointer<Void> clientData, FPDF_DWORD offset, Pointer<Void> buffer, FPDF_DWORD size)> >
WriteBlock
getter/setter pair
Callback function to write data into the current file stream.
Parameters: clientData - Pointer to user-defined data. offset - Offset position starts from the beginning of file stream. This parameter indicates writing position. buffer - Memory buffer contains data which is written into file stream. This parameter should not be NULL. size - Size of data which should be written into file stream, in bytes. Returns: 0 for success, other value for failure.
Implementation
external ffi.Pointer<
ffi.NativeFunction<
FPDF_RESULT Function(
ffi.Pointer<ffi.Void> clientData,
FPDF_DWORD offset,
ffi.Pointer<ffi.Void> buffer,
FPDF_DWORD size,
)
>
>
WriteBlock;