FPDF_FreeDefaultSystemFontInfo function
- @Native<Void Function(Pointer<
FPDF_SYSFONTINFO> )>(ffi.Pointer<FPDF_SYSFONTINFO>)>()
- Pointer<
FPDF_SYSFONTINFO> font_info
Function: FPDF_FreeDefaultSystemFontInfo Free a default system font info interface Parameters: font_info - Pointer to a FPDF_SYSFONTINFO structure Return Value: None Comments: This function should be called on the output from FPDF_GetDefaultSystemFontInfo() once it is no longer needed.
Implementation
@ffi.Native<ffi.Void Function(ffi.Pointer<FPDF_SYSFONTINFO>)>()
external void FPDF_FreeDefaultSystemFontInfo(
ffi.Pointer<FPDF_SYSFONTINFO> font_info,
);