FPDF_GetDefaultTTFMapEntry function
- @Native<Pointer<
FPDF_CharsetFontMap> Function(Size)>(ffi.Size)>()
- int index
Experimental API.
Function: FPDF_GetDefaultTTFMapEntry Returns an entry in the default character set to TT Font name map. Parameters: index - The index to the entry in the map to retrieve. Return Value: A pointer to the entry, if it is in the map, or NULL if the index is out of bounds.
Implementation
@ffi.Native<ffi.Pointer<FPDF_CharsetFontMap> Function(ffi.Size)>()
external ffi.Pointer<FPDF_CharsetFontMap> FPDF_GetDefaultTTFMapEntry(int index);