FPDF_GetPageLabel function
- @Native<UnsignedLong Function(FPDF_DOCUMENT, Int, Pointer<
Void> , UnsignedLong)>(FPDF_DOCUMENT, ffi.Int, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)>()
- FPDF_DOCUMENT document,
- int page_index,
- Pointer<
Void> buffer, - int buflen,
Get the page label for |page_index| from |document|.
document - handle to the document. page_index - the 0-based index of the page. buffer - a buffer for the page label. May be NULL. buflen - the length of the buffer, in bytes. May be 0.
Returns the number of bytes in the page label, including trailing zeros.
The |buffer| is always encoded in UTF-16LE. The |buffer| is followed by two bytes of zeros indicating the end of the string. If |buflen| is less than the returned length, or |buffer| is NULL, |buffer| will not be modified.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_DOCUMENT,
ffi.Int,
ffi.Pointer<ffi.Void>,
ffi.UnsignedLong,
)
>()
external int FPDF_GetPageLabel(
FPDF_DOCUMENT document,
int page_index,
ffi.Pointer<ffi.Void> buffer,
int buflen,
);