FPDF_GetPageSizeByIndex function
Function: FPDF_GetPageSizeByIndex Get the size of the page at the given index. Parameters: document - Handle to document. Returned by FPDF_LoadDocument. page_index - Page index, zero for the first page. width - Pointer to a double to receive the page width (in points). height - Pointer to a double to receive the page height (in points). Return value: Non-zero for success. 0 for error (document or page not found). Note: Prefer FPDF_GetPageSizeByIndexF() above. This will be deprecated in the future.
Implementation
@ffi.Native<
ffi.Int Function(
FPDF_DOCUMENT,
ffi.Int,
ffi.Pointer<ffi.Double>,
ffi.Pointer<ffi.Double>,
)
>()
external int FPDF_GetPageSizeByIndex(
FPDF_DOCUMENT document,
int page_index,
ffi.Pointer<ffi.Double> width,
ffi.Pointer<ffi.Double> height,
);