FPDF_GetSignatureObject function
- @Native<FPDF_SIGNATURE Function(FPDF_DOCUMENT, Int)>(FPDF_DOCUMENT, ffi.Int)>()
- FPDF_DOCUMENT document,
- int index
Experimental API. Function: FPDF_GetSignatureObject Get the Nth signature of the document. Parameters: document - Handle to document. Returned by FPDF_LoadDocument(). index - Index into the array of signatures of the document. Return value: Returns the handle to the signature, or NULL on failure. The caller does not take ownership of the returned FPDF_SIGNATURE. Instead, it remains valid until FPDF_CloseDocument() is called for the document.
Implementation
@ffi.Native<FPDF_SIGNATURE Function(FPDF_DOCUMENT, ffi.Int)>()
external FPDF_SIGNATURE FPDF_GetSignatureObject(
FPDF_DOCUMENT document,
int index,
);