FPDF_GetXFAPacketName function
- @Native<UnsignedLong Function(FPDF_DOCUMENT, Int, Pointer<
Void> , UnsignedLong)>(FPDF_DOCUMENT, ffi.Int, ffi.Pointer<ffi.Void>, ffi.UnsignedLong)>()
- FPDF_DOCUMENT document,
- int index,
- Pointer<
Void> buffer, - int buflen,
Experimental API. Function: FPDF_GetXFAPacketName Get the name of a packet in the XFA array. Parameters: document - Handle to the document. index - Index number of the packet. 0 for the first packet. buffer - Buffer for holding the name of the XFA packet. buflen - Length of |buffer| in bytes. Return value: The length of the packet name in bytes, or 0 on error.
|document| must be valid and |index| must be in the range [0, N), where N is the value returned by FPDF_GetXFAPacketCount(). |buffer| is only modified if it is non-NULL and |buflen| is greater than or equal to the length of the packet name. The packet name includes a terminating NUL character. |buffer| is unmodified on error.
Implementation
@ffi.Native<
ffi.UnsignedLong Function(
FPDF_DOCUMENT,
ffi.Int,
ffi.Pointer<ffi.Void>,
ffi.UnsignedLong,
)
>()
external int FPDF_GetXFAPacketName(
FPDF_DOCUMENT document,
int index,
ffi.Pointer<ffi.Void> buffer,
int buflen,
);