FPDF_RenderPageBitmapWithMatrix function
Function: FPDF_RenderPageBitmapWithMatrix Render contents of a page to a device independent bitmap. Parameters: bitmap - Handle to the device independent bitmap (as the output buffer). The bitmap handle can be created by FPDFBitmap_Create or retrieved by FPDFImageObj_GetBitmap. page - Handle to the page. Returned by FPDF_LoadPage. matrix - The transform matrix, which must be invertible. See PDF Reference 1.7, 4.2.2 Common Transformations. clipping - The rect to clip to in device coords. flags - 0 for normal display, or combination of the Page Rendering flags defined above. With the FPDF_ANNOT flag, it renders all annotations that do not require user-interaction, which are all annotations except widget and popup annotations. Return value: None. Note that behavior is undefined if det of |matrix| is 0.
Implementation
@ffi.Native<
ffi.Void Function(
FPDF_BITMAP,
FPDF_PAGE,
ffi.Pointer<FS_MATRIX>,
ffi.Pointer<FS_RECTF>,
ffi.Int,
)
>()
external void FPDF_RenderPageBitmapWithMatrix(
FPDF_BITMAP bitmap,
FPDF_PAGE page,
ffi.Pointer<FS_MATRIX> matrix,
ffi.Pointer<FS_RECTF> clipping,
int flags,
);