FPDF_SetSystemFontInfo function
- @Native<Void Function(Pointer<
FPDF_SYSFONTINFO> )>(ffi.Pointer<FPDF_SYSFONTINFO>)>()
- Pointer<
FPDF_SYSFONTINFO> font_info
Function: FPDF_SetSystemFontInfo Set the system font info interface into PDFium Parameters: font_info - Pointer to a FPDF_SYSFONTINFO structure Return Value: None Comments: Platform support implementation should implement required methods of FFDF_SYSFONTINFO interface, then call this function during PDFium initialization process.
Call this with NULL to tell PDFium to stop using a previously set |FPDF_SYSFONTINFO|.
Implementation
@ffi.Native<ffi.Void Function(ffi.Pointer<FPDF_SYSFONTINFO>)>()
external void FPDF_SetSystemFontInfo(ffi.Pointer<FPDF_SYSFONTINFO> font_info);