FPDF_StructElement_Attr_GetBlobValue function
- @Native<FPDF_BOOL Function(FPDF_STRUCTELEMENT_ATTR_VALUE, Pointer<
Void> , UnsignedLong, Pointer<UnsignedLong> )>(FPDF_STRUCTELEMENT_ATTR_VALUE, ffi.Pointer<ffi.Void>, ffi.UnsignedLong, ffi.Pointer<ffi.UnsignedLong>)>()
- FPDF_STRUCTELEMENT_ATTR_VALUE value,
- Pointer<
Void> buffer, - int buflen,
- Pointer<
UnsignedLong> out_buflen,
Experimental API. Function: FPDF_StructElement_Attr_GetBlobValue Get the value of a blob attribute in an attribute map as string. Parameters: value - Handle to the value. buffer - A buffer for holding the returned value. This is only modified if |buflen| is at least as long as the length of the value. Optional, pass null to just retrieve the size of the buffer needed. buflen - The length of the buffer. out_buflen - A pointer to variable that will receive the minimum buffer size to contain the key. Not filled if FALSE is returned. Return value: Returns TRUE if the attribute maps to a string value, FALSE otherwise.
Implementation
@ffi.Native<
FPDF_BOOL Function(
FPDF_STRUCTELEMENT_ATTR_VALUE,
ffi.Pointer<ffi.Void>,
ffi.UnsignedLong,
ffi.Pointer<ffi.UnsignedLong>,
)
>()
external int FPDF_StructElement_Attr_GetBlobValue(
FPDF_STRUCTELEMENT_ATTR_VALUE value,
ffi.Pointer<ffi.Void> buffer,
int buflen,
ffi.Pointer<ffi.UnsignedLong> out_buflen,
);