FPDF_StructElement_Attr_GetBooleanValue function
- @Native<FPDF_BOOL Function(FPDF_STRUCTELEMENT_ATTR_VALUE, Pointer<
Int> )>(FPDF_STRUCTELEMENT_ATTR_VALUE, ffi.Pointer<FPDF_BOOL>)>()
- FPDF_STRUCTELEMENT_ATTR_VALUE value,
- Pointer<
Int> out_value
Experimental API. Function: FPDF_StructElement_Attr_GetBooleanValue Get the value of a boolean attribute in an attribute map as FPDF_BOOL. FPDF_StructElement_Attr_GetType() should have returned FPDF_OBJECT_BOOLEAN for this property. Parameters: value - Handle to the value. out_value - A pointer to variable that will receive the value. Not filled if false is returned. Return value: Returns TRUE if the attribute maps to a boolean value, FALSE otherwise.
Implementation
@ffi.Native<
FPDF_BOOL Function(FPDF_STRUCTELEMENT_ATTR_VALUE, ffi.Pointer<FPDF_BOOL>)
>()
external int FPDF_StructElement_Attr_GetBooleanValue(
FPDF_STRUCTELEMENT_ATTR_VALUE value,
ffi.Pointer<FPDF_BOOL> out_value,
);