FORM_CanUndo method
Function: FORM_CanUndo Find out if it is possible for the current focused widget in a given form to perform an undo operation. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). Return Value: True if it is possible to undo.
Implementation
int FORM_CanUndo(FPDF_FORMHANDLE hHandle, FPDF_PAGE page) {
return _FORM_CanUndo(hHandle, page);
}