FORM_GetFocusedText method

int FORM_GetFocusedText(
  1. FPDF_FORMHANDLE hHandle,
  2. FPDF_PAGE page,
  3. Pointer<Void> buffer,
  4. int buflen,
)

Experimental API Function: FORM_GetFocusedText Call this function to obtain the text within the current focused field, if any. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). buffer - Buffer for holding the form text, encoded in UTF-16LE. If NULL, |buffer| is not modified. buflen - Length of |buffer| in bytes. If |buflen| is less than the length of the form text string, |buffer| is not modified. Return Value: Length in bytes for the text in the focused field.

Implementation

int FORM_GetFocusedText(
  FPDF_FORMHANDLE hHandle,
  FPDF_PAGE page,
  ffi.Pointer<ffi.Void> buffer,
  int buflen,
) {
  return _FORM_GetFocusedText(hHandle, page, buffer, buflen);
}