FORM_OnRButtonDown method
int
FORM_OnRButtonDown(
- FPDF_FORMHANDLE hHandle,
- FPDF_PAGE page,
- int modifier,
- double page_x,
- double page_y,
Function: FORM_OnRButtonDown Same as above, execpt for the right mouse button. Comments: At the present time, has no effect except in XFA builds, but is included for the sake of symmetry.
Implementation
int FORM_OnRButtonDown(
FPDF_FORMHANDLE hHandle,
FPDF_PAGE page,
int modifier,
double page_x,
double page_y,
) {
return _FORM_OnRButtonDown(hHandle, page, modifier, page_x, page_y);
}