FORM_SelectAllText method
Experimental API Function: FORM_SelectAllText Call this function to select all the text within the currently focused form text field or form combobox text field. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). Return Value: Whether the operation succeeded or not.
Implementation
int FORM_SelectAllText(FPDF_FORMHANDLE hHandle, FPDF_PAGE page) {
return _FORM_SelectAllText(hHandle, page);
}