FORM_Undo method
Function: FORM_Undo Make the current focused widget perform an undo operation. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). page - Handle to the page, as returned by FPDF_LoadPage(). Return Value: True if the undo operation succeeded.
Implementation
int FORM_Undo(FPDF_FORMHANDLE hHandle, FPDF_PAGE page) {
return _FORM_Undo(hHandle, page);
}