FPDFAnnot_GetOptionCount method
Experimental API. Get the number of options in the |annot|'s "Opt" dictionary. Intended for use with listbox and combobox widget annotations.
hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation.
Returns the number of options in "Opt" dictionary on success. Return value will be -1 if annotation does not have an "Opt" dictionary or other error.
Implementation
int FPDFAnnot_GetOptionCount(FPDF_FORMHANDLE hHandle, FPDF_ANNOTATION annot) {
return _FPDFAnnot_GetOptionCount(hHandle, annot);
}