FPDFAnnot_GetVertices method
Experimental API. Get the vertices of a polygon or polyline annotation. |buffer| is an array of points of the annotation. If |length| is less than the returned length, or |annot| or |buffer| is NULL, |buffer| will not be modified.
annot - handle to an annotation, as returned by e.g. FPDFPage_GetAnnot() buffer - buffer for holding the points. length - length of the buffer in points.
Returns the number of points if the annotation is of type polygon or polyline, 0 otherwise.
Implementation
int FPDFAnnot_GetVertices(
FPDF_ANNOTATION annot,
ffi.Pointer<FS_POINTF> buffer,
int length,
) {
return _FPDFAnnot_GetVertices(annot, buffer, length);
}