FPDFAnnot_IsChecked method
Experimental API. Determine if |annot| is a form widget that is checked. Intended for use with checkbox and radio button widgets.
hHandle - handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment. annot - handle to an annotation.
Returns true if |annot| is a form widget and is checked, false otherwise.
Implementation
int FPDFAnnot_IsChecked(FPDF_FORMHANDLE hHandle, FPDF_ANNOTATION annot) {
return _FPDFAnnot_IsChecked(hHandle, annot);
}