FPDFAnnot_SetBorder method

int FPDFAnnot_SetBorder(
  1. FPDF_ANNOTATION annot,
  2. double horizontal_radius,
  3. double vertical_radius,
  4. double border_width,
)

Experimental API. Set the characteristics of the annotation's border (rounded rectangle).

annot - handle to an annotation horizontal_radius - horizontal corner radius, in default user space units vertical_radius - vertical corner radius, in default user space units border_width - border width, in default user space units

Returns true if setting the border for |annot| succeeds, false otherwise.

If |annot| contains an appearance stream that overrides the border values, then the appearance stream will be removed on success.

Implementation

int FPDFAnnot_SetBorder(
  FPDF_ANNOTATION annot,
  double horizontal_radius,
  double vertical_radius,
  double border_width,
) {
  return _FPDFAnnot_SetBorder(
    annot,
    horizontal_radius,
    vertical_radius,
    border_width,
  );
}