FPDFAnnot_SetFormFieldFlags method

int FPDFAnnot_SetFormFieldFlags(
  1. FPDF_FORMHANDLE handle,
  2. FPDF_ANNOTATION annot,
  3. int flags
)

Experimental API. Sets the form field flags for an interactive form annotation.

handle - the handle to the form fill module, returned by FPDFDOC_InitFormFillEnvironment(). annot - handle to an interactive form annotation. flags - the form field flags to be set.

Returns true if successful.

Implementation

int FPDFAnnot_SetFormFieldFlags(
  FPDF_FORMHANDLE handle,
  FPDF_ANNOTATION annot,
  int flags,
) {
  return _FPDFAnnot_SetFormFieldFlags(handle, annot, flags);
}