FPDFAvail_GetFirstPageNum method
Get the page number for the first available page in a linearized PDF.
doc - document handle.
Returns the zero-based index for the first available page.
For most linearized PDFs, the first available page will be the first page, however, some PDFs might make another page the first available page. For non-linearized PDFs, this function will always return zero.
Implementation
int FPDFAvail_GetFirstPageNum(FPDF_DOCUMENT doc) {
return _FPDFAvail_GetFirstPageNum(doc);
}