FPDFBitmap_Destroy method
Function: FPDFBitmap_Destroy Destroy a bitmap and release all related buffers. Parameters: bitmap - Handle to the bitmap. Returned by FPDFBitmap_Create or FPDFImageObj_GetBitmap. Return value: None. Comments: This function will not destroy any external buffers provided when the bitmap was created.
Implementation
void FPDFBitmap_Destroy(FPDF_BITMAP bitmap) {
return _FPDFBitmap_Destroy(bitmap);
}