FPDFBookmark_GetFirstChild method
Get the first child of |bookmark|, or the first top-level bookmark item.
document - handle to the document. bookmark - handle to the current bookmark. Pass NULL for the first top level item.
Returns a handle to the first child of |bookmark| or the first top-level bookmark item. NULL if no child or top-level bookmark found. Note that another name for the bookmarks is the document outline, as described in ISO 32000-1:2008, section 12.3.3.
Implementation
FPDF_BOOKMARK FPDFBookmark_GetFirstChild(
FPDF_DOCUMENT document,
FPDF_BOOKMARK bookmark,
) {
return _FPDFBookmark_GetFirstChild(document, bookmark);
}