FPDFDoc_DeleteAttachment method

int FPDFDoc_DeleteAttachment(
  1. FPDF_DOCUMENT document,
  2. int index
)

Experimental API. Delete the embedded attachment at |index| in |document|. Note that this does not remove the attachment data from the PDF file; it simply removes the file's entry in the embedded files name tree so that it does not appear in the attachment list. This behavior may change in the future.

document - handle to a document. index - the index of the embedded file to be deleted.

Returns true if successful.

Implementation

int FPDFDoc_DeleteAttachment(FPDF_DOCUMENT document, int index) {
  return _FPDFDoc_DeleteAttachment(document, index);
}