FPDFLink_GetLinkAtPoint method
Find a link at point (|x|,|y|) on |page|.
page - handle to the document page. x - the x coordinate, in the page coordinate system. y - the y coordinate, in the page coordinate system.
Returns a handle to the link, or NULL if no link found at the given point.
You can convert coordinates from screen coordinates to page coordinates using FPDF_DeviceToPage().
Implementation
FPDF_LINK FPDFLink_GetLinkAtPoint(FPDF_PAGE page, double x, double y) {
return _FPDFLink_GetLinkAtPoint(page, x, y);
}