FPDFLink_GetRect method
Function: FPDFLink_GetRect Fetch the boundaries of a rectangle for a link. Parameters: link_page - Handle returned by FPDFLink_LoadWebLinks. link_index - Zero-based index for the link. rect_index - Zero-based index for a rectangle. left - Pointer to a double value receiving the rectangle left boundary. top - Pointer to a double value receiving the rectangle top boundary. right - Pointer to a double value receiving the rectangle right boundary. bottom - Pointer to a double value receiving the rectangle bottom boundary. Return Value: On success, return TRUE and fill in |left|, |top|, |right|, and |bottom|. If |link_page| is invalid or if |link_index| does not correspond to a valid link, then return FALSE, and the out parameters remain unmodified.
Implementation
int FPDFLink_GetRect(
FPDF_PAGELINK link_page,
int link_index,
int rect_index,
ffi.Pointer<ffi.Double> left,
ffi.Pointer<ffi.Double> top,
ffi.Pointer<ffi.Double> right,
ffi.Pointer<ffi.Double> bottom,
) {
return _FPDFLink_GetRect(
link_page,
link_index,
rect_index,
left,
top,
right,
bottom,
);
}