FPDFPageObj_CreateNewRect method
Create a closed path consisting of a rectangle.
x - horizontal position for the left boundary of the rectangle. y - vertical position for the bottom boundary of the rectangle. w - width of the rectangle. h - height of the rectangle.
Returns a handle to the new path object.
Implementation
FPDF_PAGEOBJECT FPDFPageObj_CreateNewRect(
double x,
double y,
double w,
double h,
) {
return _FPDFPageObj_CreateNewRect(x, y, w, h);
}