FPDFPageObj_GetIsActive method
Experimental API. Gets active state for |page_object| within page.
page_object - handle to a page object. active - pointer to variable that will receive if the page object is active. This is a required parameter. Not filled if FALSE is returned.
For page objects where |active| is filled with FALSE, the |page_object| is treated as if it wasn't in the document even though it is still held internally.
Returns TRUE if the operation succeeded, FALSE if it failed.
Implementation
int FPDFPageObj_GetIsActive(
FPDF_PAGEOBJECT page_object,
ffi.Pointer<FPDF_BOOL> active,
) {
return _FPDFPageObj_GetIsActive(page_object, active);
}