FPDFPageObj_RemoveMark method

int FPDFPageObj_RemoveMark(
  1. FPDF_PAGEOBJECT page_object,
  2. FPDF_PAGEOBJECTMARK mark
)

Experimental API. Removes a content |mark| from a |page_object|. The mark handle will be invalid after the removal.

page_object - handle to a page object. mark - handle to a content mark in that object to remove.

Returns TRUE if the operation succeeded, FALSE if it failed.

Implementation

int FPDFPageObj_RemoveMark(
  FPDF_PAGEOBJECT page_object,
  FPDF_PAGEOBJECTMARK mark,
) {
  return _FPDFPageObj_RemoveMark(page_object, mark);
}