FPDFPage_InsertClipPath method

void FPDFPage_InsertClipPath(
  1. FPDF_PAGE page,
  2. FPDF_CLIPPATH clipPath
)

Clip the page content, the page content that outside the clipping region become invisible.

A clip path will be inserted before the page content stream or content array. In this way, the page content will be clipped by this clip path.

page - A page handle. clipPath - A handle to the clip path. (Does not take ownership.)

Implementation

void FPDFPage_InsertClipPath(FPDF_PAGE page, FPDF_CLIPPATH clipPath) {
  return _FPDFPage_InsertClipPath(page, clipPath);
}