FPDFPath_Close method
Close the current subpath of a given path.
path - the handle to the path object.
This will add a line between the current point and the initial point of the subpath, thus terminating the current subpath.
Returns TRUE on success
Implementation
int FPDFPath_Close(FPDF_PAGEOBJECT path) {
return _FPDFPath_Close(path);
}