FPDFText_CountChars method

int FPDFText_CountChars(
  1. FPDF_TEXTPAGE text_page
)

Function: FPDFText_CountChars Get number of characters in a page. Parameters: text_page - Handle to a text page information structure. Returned by FPDFText_LoadPage function. Return value: Number of characters in the page. Return -1 for error. Generated characters, like additional space characters, new line characters, are also counted. Comments: Characters in a page form a "stream", inside the stream, each character has an index. We will use the index parameters in many of FPDFTEXT functions. The first character in the page has an index value of zero.

Implementation

int FPDFText_CountChars(FPDF_TEXTPAGE text_page) {
  return _FPDFText_CountChars(text_page);
}