FPDFText_HasUnicodeMapError method
Experimental API. Function: FPDFText_HasUnicodeMapError Get if a character in a page has an invalid unicode mapping. Parameters: text_page - Handle to a text page information structure. Returned by FPDFText_LoadPage function. index - Zero-based index of the character. Return value: 1 if the character has an invalid unicode mapping. 0 if the character has no known unicode mapping issues. -1 if there was an error.
Implementation
int FPDFText_HasUnicodeMapError(FPDF_TEXTPAGE text_page, int index) {
return _FPDFText_HasUnicodeMapError(text_page, index);
}