FPDF_FreeDefaultSystemFontInfo method

void FPDF_FreeDefaultSystemFontInfo(
  1. Pointer<FPDF_SYSFONTINFO> font_info
)

Function: FPDF_FreeDefaultSystemFontInfo Free a default system font info interface Parameters: font_info - Pointer to a FPDF_SYSFONTINFO structure Return Value: None Comments: This function should be called on the output from FPDF_GetDefaultSystemFontInfo() once it is no longer needed.

Implementation

void FPDF_FreeDefaultSystemFontInfo(ffi.Pointer<FPDF_SYSFONTINFO> font_info) {
  return _FPDF_FreeDefaultSystemFontInfo(font_info);
}