FPDF_GetDefaultTTFMapEntry method

Pointer<FPDF_CharsetFontMap> FPDF_GetDefaultTTFMapEntry(
  1. int index
)

Experimental API.

Function: FPDF_GetDefaultTTFMapEntry Returns an entry in the default character set to TT Font name map. Parameters: index - The index to the entry in the map to retrieve. Return Value: A pointer to the entry, if it is in the map, or NULL if the index is out of bounds.

Implementation

ffi.Pointer<FPDF_CharsetFontMap> FPDF_GetDefaultTTFMapEntry(int index) {
  return _FPDF_GetDefaultTTFMapEntry(index);
}