FPDF_GetLastError method
Function: FPDF_GetLastError Get last error code when a function fails. Parameters: None. Return value: A 32-bit integer indicating error code as defined above. Comments: If the previous SDK call succeeded, the return value of this function is not defined. This function only works in conjunction with APIs that mention FPDF_GetLastError() in their documentation.
Implementation
int FPDF_GetLastError() {
return _FPDF_GetLastError();
}