FPDF_GetSignatureObject method
Experimental API. Function: FPDF_GetSignatureObject Get the Nth signature of the document. Parameters: document - Handle to document. Returned by FPDF_LoadDocument(). index - Index into the array of signatures of the document. Return value: Returns the handle to the signature, or NULL on failure. The caller does not take ownership of the returned FPDF_SIGNATURE. Instead, it remains valid until FPDF_CloseDocument() is called for the document.
Implementation
FPDF_SIGNATURE FPDF_GetSignatureObject(FPDF_DOCUMENT document, int index) {
return _FPDF_GetSignatureObject(document, index);
}