FPDF_GetTrailerEnds method

int FPDF_GetTrailerEnds(
  1. FPDF_DOCUMENT document,
  2. Pointer<UnsignedInt> buffer,
  3. int length
)

Experimental API. Function: FPDF_GetTrailerEnds Get the byte offsets of trailer ends. Parameters: document - Handle to document. Returned by FPDF_LoadDocument(). buffer - The address of a buffer that receives the byte offsets. length - The size, in ints, of |buffer|. Return value: Returns the number of ints in the buffer on success, 0 on error.

|buffer| is an array of integers that describes the exact byte offsets of the trailer ends in the document. If |length| is less than the returned length, or |document| or |buffer| is NULL, |buffer| will not be modified.

Implementation

int FPDF_GetTrailerEnds(
  FPDF_DOCUMENT document,
  ffi.Pointer<ffi.UnsignedInt> buffer,
  int length,
) {
  return _FPDF_GetTrailerEnds(document, buffer, length);
}