FPDF_SetFormFieldHighlightAlpha method

void FPDF_SetFormFieldHighlightAlpha(
  1. FPDF_FORMHANDLE hHandle,
  2. int alpha
)

Function: FPDF_SetFormFieldHighlightAlpha Set the transparency of the form field highlight color in the document. Parameters: hHandle - Handle to the form fill module, as returned by FPDFDOC_InitFormFillEnvironment(). doc - Handle to the document, as returaned by FPDF_LoadDocument(). alpha - The transparency of the form field highlight color, between 0-255. Return Value: None.

Implementation

void FPDF_SetFormFieldHighlightAlpha(FPDF_FORMHANDLE hHandle, int alpha) {
  return _FPDF_SetFormFieldHighlightAlpha(hHandle, alpha);
}