FPDF_VIEWERREF_GetDuplex method
Function: FPDF_VIEWERREF_GetDuplex Returns the paper handling option to be used when printing from the print dialog. Parameters: document - Handle to the loaded document. Return value: The paper handling option to be used when printing.
Implementation
_FPDF_DUPLEXTYPE_ FPDF_VIEWERREF_GetDuplex(FPDF_DOCUMENT document) {
return _FPDF_DUPLEXTYPE_.fromValue(_FPDF_VIEWERREF_GetDuplex(document));
}